-- freeslot globalization by GenericHeroGuy

local firstsfx, firstspr, firststate, firstmt

local realfreeslot = freeslot
rawset(_G, "freeslot", function(...)
	local ret = {}
	for _, v in ipairs{...} do
		if pcall(do if _G[v] == nil then error() end end) then
			print(v.." already exists")
			table.insert(ret, _G[v])
			continue
		end
		local r = realfreeslot(v)
		rawset(_G, v, _G[v])
		table.insert(ret, r)
	end
	return unpack(ret)
end)


-- fun fact: skins actually have 32 sounds: 21 unused sounds from vanilla SRB2, plus 11 new sounds for kart
-- both of these are counted in NUMSKINSOUNDS, which means the game allocates 8160 freeslots for skinsounds, rather than the 2805 it actually needs
-- so technically, you actually have 6955 freeslots dedicated to SFX rather than 1600
-- but none of this matters because SFX and skin sounds share the same pool anyway

COM_AddCommand("listfreeslots", function(p)
	local numsfx = 0
	for i = firstsfx, #sfxinfo - 1 do
		if sfxinfo[i].priority ~= 0 then
			numsfx = $ + 1
		else
			break
		end
	end

	local numspr = 0
	for i = firstspr, #sprnames - 1 do
		if tonumber(sprnames[i]) == nil then
			numspr = $ + 1
		else
			break
		end
	end

	local numstate = 0
	for i = firststate, #states - 1 do
		local s = states[i]
		--print(i..": "..s.sprite.." "..s.frame.." "..s.tics.." "..tostring(s.action).." "..s.var1.." "..s.var2.." "..s.nextstate)
		if not (s.sprite == 0 and s.frame == 0 and s.tics == 0 and s.action == nil and s.var1 == 0 and s.var2 == 0 and s.nextstate == 0) then
			numstate = i - firststate + 1
		end
		-- can't break the loop because some addons freeslot states without defining them
	end

	local nummt = 0
	for i = firstmt, #mobjinfo - 1 do
		local mt = mobjinfo[i]
		--print(i..": "..mt.doomednum.." "..mt.spawnstate.." "..mt.spawnhealth.." "..mt.seestate.." "..mt.seesound.." "..mt.reactiontime.." "..mt.attacksound.." "..mt.painstate.." "..mt.painchance.." "..mt.painsound.." "..mt.meleestate.." "..mt.missilestate.." "..mt.deathstate.." "..mt.xdeathstate.." "..mt.deathsound.." "..mt.speed.." "..mt.radius.." "..mt.height.." "..mt.dispoffset.." "..mt.mass.." "..mt.damage.." "..mt.activesound.." "..mt.flags.." "..mt.raisestate)
		if not (mt.spawnstate == 0 and mt.spawnhealth == 0 and mt.seestate == 0 and mt.seesound == 0 and mt.reactiontime == 0 and mt.attacksound == 0 and mt.painstate == 0 and mt.painchance == 0 and mt.painsound == 0 and mt.meleestate == 0 and mt.missilestate == 0 and mt.deathstate == 0 and mt.xdeathstate == 0 and mt.deathsound == 0 and mt.speed == 0 and mt.radius == 0 and mt.height == 0 and mt.dispoffset == 0 and mt.mass == 0 and mt.damage == 0 and mt.activesound == 0 and mt.flags == 0 and mt.raisestate == 0) then
			nummt = i - firstmt + 1
		end
		-- can't break here either
	end

	local skinsounds = (#skins - 1)*11 -- sonic's sounds don't count

	print("Freeslot usage:")
	print("SFX: "..(numsfx - skinsounds).."/"..(#sfxinfo - firstsfx - skinsounds))
	print("Sprites: "..numspr.."/"..(#sprnames - firstspr))
	print("States: "..numstate.."/"..(#states - firststate))
	print("Mobjs: "..nummt.."/"..(#mobjinfo - firstmt))
end, COM_LOCAL)

-- globalize and count SFX
for i = 0, #sfxinfo - 1 do
	local sfx = sfxinfo[i]
	if sfx.priority ~= 0 then
		firstsfx = i + 1
		--print(i..": sfx_"..sfx.name)
		if _G["sfx_"..sfx.name] == i then
			rawset(_G, "sfx_"..sfx.name, i)
		else
			print("WTF")
		end
	elseif firstsfx then
		break
	end
end

-- globalize and count sprites
for i = 0, #sprnames - 1 do
	local name = sprnames[i]
	if tonumber(name) == nil then
		--print(i..": SPR_"..name)
		if _G["SPR_"..name] == i then
			rawset(_G, "SPR_"..name, i)
			firstspr = i + 1
		else
			print("WTF")
		end
	end
end

-- globalize mobjs and states
local function globalize(t)
	for k, v in pairs(t) do
		--print(k..": "..v)
		if _G[v] == k then
			rawset(_G, v, k)
		else
			print("WTF")
		end
	end
end

local mobjs = {
	[0] = "MT_NULL",
	"MT_UNKNOWN",
	"MT_THOK",
	"MT_PLAYER",
	"MT_BLUECRAWLA",
	"MT_REDCRAWLA",
	"MT_GFZFISH",
	"MT_GOLDBUZZ",
	"MT_REDBUZZ",
	"MT_AQUABUZZ",
	"MT_JETTBOMBER",
	"MT_JETTGUNNER",
	"MT_CRAWLACOMMANDER",
	"MT_DETON",
	"MT_SKIM",
	"MT_TURRET",
	"MT_POPUPTURRET",
	"MT_SHARP",
	"MT_JETJAW",
	"MT_SNAILER",
	"MT_VULTURE",
	"MT_POINTY",
	"MT_POINTYBALL",
	"MT_ROBOHOOD",
	"MT_FACESTABBER",
	"MT_EGGGUARD",
	"MT_EGGSHIELD",
	"MT_GSNAPPER",
	"MT_MINUS",
	"MT_SPRINGSHELL",
	"MT_YELLOWSHELL",
	"MT_UNIDUS",
	"MT_UNIBALL",
	"MT_BOSSEXPLODE",
	"MT_SONIC3KBOSSEXPLODE",
	"MT_BOSSFLYPOINT",
	"MT_EGGTRAP",
	"MT_BOSS3WAYPOINT",
	"MT_BOSS9GATHERPOINT",
	"MT_EGGMOBILE",
	"MT_JETFUME1",
	"MT_EGGMOBILE_BALL",
	"MT_EGGMOBILE_TARGET",
	"MT_EGGMOBILE_FIRE",
	"MT_EGGMOBILE2",
	"MT_EGGMOBILE2_POGO",
	"MT_BOSSTANK1",
	"MT_BOSSTANK2",
	"MT_BOSSSPIGOT",
	"MT_GOOP",
	"MT_EGGMOBILE3",
	"MT_PROPELLER",
	"MT_FAKEMOBILE",
	"MT_EGGMOBILE4",
	"MT_EGGMOBILE4_MACE",
	"MT_JETFLAME",
	"MT_BLACKEGGMAN",
	"MT_BLACKEGGMAN_HELPER",
	"MT_BLACKEGGMAN_GOOPFIRE",
	"MT_BLACKEGGMAN_MISSILE",
	"MT_CYBRAKDEMON",
	"MT_CYBRAKDEMON_ELECTRIC_BARRIER",
	"MT_CYBRAKDEMON_MISSILE",
	"MT_CYBRAKDEMON_FLAMESHOT",
	"MT_CYBRAKDEMON_FLAMEREST",
	"MT_CYBRAKDEMON_TARGET_RETICULE",
	"MT_CYBRAKDEMON_TARGET_DOT",
	"MT_CYBRAKDEMON_NAPALM_BOMB_LARGE",
	"MT_CYBRAKDEMON_NAPALM_BOMB_SMALL",
	"MT_CYBRAKDEMON_NAPALM_FLAMES",
	"MT_CYBRAKDEMON_VILE_EXPLOSION",
	"MT_METALSONIC_RACE",
	"MT_METALSONIC_BATTLE",
	"MT_MSSHIELD_FRONT",
	"MT_MSGATHER",
	"MT_RING",
	"MT_FLINGRING",
	"MT_BLUEBALL",
	"MT_REDTEAMRING",
	"MT_BLUETEAMRING",
	"MT_EMMY",
	"MT_TOKEN",
	"MT_REDFLAG",
	"MT_BLUEFLAG",
	"MT_EMBLEM",
	"MT_EMERALD1",
	"MT_EMERALD2",
	"MT_EMERALD3",
	"MT_EMERALD4",
	"MT_EMERALD5",
	"MT_EMERALD6",
	"MT_EMERALD7",
	"MT_EMERHUNT",
	"MT_EMERALDSPAWN",
	"MT_FLINGEMERALD",
	"MT_FAN",
	"MT_STEAM",
	"MT_BLUESPRING",
	"MT_YELLOWSPRING",
	"MT_REDSPRING",
	"MT_YELLOWDIAG",
	"MT_REDDIAG",
	"MT_BUBBLES",
	"MT_SIGN",
	"MT_SPIKEBALL",
	"MT_SPECIALSPIKEBALL",
	"MT_SPINFIRE",
	"MT_SPIKE",
	"MT_STARPOST",
	"MT_BIGMINE",
	"MT_BIGAIRMINE",
	"MT_CANNONLAUNCHER",
	"MT_SUPERRINGBOX",
	"MT_REDRINGBOX",
	"MT_BLUERINGBOX",
	"MT_SNEAKERTV",
	"MT_INV",
	"MT_PRUP",
	"MT_YELLOWTV",
	"MT_BLUETV",
	"MT_BLACKTV",
	"MT_WHITETV",
	"MT_GREENTV",
	"MT_PITYTV",
	"MT_EGGMANBOX",
	"MT_MIXUPBOX",
	"MT_RECYCLETV",
	"MT_RECYCLEICO",
	"MT_QUESTIONBOX",
	"MT_GRAVITYBOX",
	"MT_SCORETVSMALL",
	"MT_SCORETVLARGE",
	"MT_MONITOREXPLOSION",
	"MT_REDMONITOREXPLOSION",
	"MT_BLUEMONITOREXPLOSION",
	"MT_RINGICO",
	"MT_SHOESICO",
	"MT_INVCICO",
	"MT_1UPICO",
	"MT_YSHIELDICO",
	"MT_BSHIELDICO",
	"MT_KSHIELDICO",
	"MT_WSHIELDICO",
	"MT_GSHIELDICO",
	"MT_PITYSHIELDICO",
	"MT_EGGMANICO",
	"MT_MIXUPICO",
	"MT_GRAVITYICO",
	"MT_SCOREICOSMALL",
	"MT_SCOREICOLARGE",
	"MT_ROCKET",
	"MT_LASER",
	"MT_TORPEDO",
	"MT_TORPEDO2",
	"MT_ENERGYBALL",
	"MT_MINE",
	"MT_JETTBULLET",
	"MT_TURRETLASER",
	"MT_CANNONBALL",
	"MT_CANNONBALLDECOR",
	"MT_ARROW",
	"MT_DEMONFIRE",
	"MT_GFZFLOWER1",
	"MT_GFZFLOWER2",
	"MT_GFZFLOWER3",
	"MT_BERRYBUSH",
	"MT_BUSH",
	"MT_THZPLANT",
	"MT_ALARM",
	"MT_GARGOYLE",
	"MT_SEAWEED",
	"MT_WATERDRIP",
	"MT_WATERDROP",
	"MT_CORAL1",
	"MT_CORAL2",
	"MT_CORAL3",
	"MT_BLUECRYSTAL",
	"MT_CHAIN",
	"MT_FLAME",
	"MT_EGGSTATUE",
	"MT_MACEPOINT",
	"MT_SWINGMACEPOINT",
	"MT_HANGMACEPOINT",
	"MT_SPINMACEPOINT",
	"MT_HIDDEN_SLING",
	"MT_SMALLMACECHAIN",
	"MT_BIGMACECHAIN",
	"MT_SMALLMACE",
	"MT_BIGMACE",
	"MT_CEZFLOWER",
	"MT_BIGTUMBLEWEED",
	"MT_LITTLETUMBLEWEED",
	"MT_CACTI1",
	"MT_CACTI2",
	"MT_CACTI3",
	"MT_CACTI4",
	"MT_FLAMEJET",
	"MT_VERTICALFLAMEJET",
	"MT_FLAMEJETFLAME",
	"MT_FJSPINAXISA",
	"MT_FJSPINHELPERA",
	"MT_FJSPINAXISB",
	"MT_FJSPINHELPERB",
	"MT_FLAMEJETFLAMEB",
	"MT_TRAPGOYLE",
	"MT_TRAPGOYLEUP",
	"MT_TRAPGOYLEDOWN",
	"MT_TRAPGOYLELONG",
	"MT_TARGET",
	"MT_STALAGMITE0",
	"MT_STALAGMITE1",
	"MT_STALAGMITE2",
	"MT_STALAGMITE3",
	"MT_STALAGMITE4",
	"MT_STALAGMITE5",
	"MT_STALAGMITE6",
	"MT_STALAGMITE7",
	"MT_STALAGMITE8",
	"MT_STALAGMITE9",
	"MT_XMASPOLE",
	"MT_CANDYCANE",
	"MT_SNOWMAN",
	"MT_SNOWMANHAT",
	"MT_LAMPPOST1",
	"MT_LAMPPOST2",
	"MT_HANGSTAR",
	"MT_BSZTALLFLOWER_RED",
	"MT_BSZTALLFLOWER_PURPLE",
	"MT_BSZTALLFLOWER_BLUE",
	"MT_BSZTALLFLOWER_CYAN",
	"MT_BSZTALLFLOWER_YELLOW",
	"MT_BSZTALLFLOWER_ORANGE",
	"MT_BSZFLOWER_RED",
	"MT_BSZFLOWER_PURPLE",
	"MT_BSZFLOWER_BLUE",
	"MT_BSZFLOWER_CYAN",
	"MT_BSZFLOWER_YELLOW",
	"MT_BSZFLOWER_ORANGE",
	"MT_BSZSHORTFLOWER_RED",
	"MT_BSZSHORTFLOWER_PURPLE",
	"MT_BSZSHORTFLOWER_BLUE",
	"MT_BSZSHORTFLOWER_CYAN",
	"MT_BSZSHORTFLOWER_YELLOW",
	"MT_BSZSHORTFLOWER_ORANGE",
	"MT_BSZTULIP_RED",
	"MT_BSZTULIP_PURPLE",
	"MT_BSZTULIP_BLUE",
	"MT_BSZTULIP_CYAN",
	"MT_BSZTULIP_YELLOW",
	"MT_BSZTULIP_ORANGE",
	"MT_BSZCLUSTER_RED",
	"MT_BSZCLUSTER_PURPLE",
	"MT_BSZCLUSTER_BLUE",
	"MT_BSZCLUSTER_CYAN",
	"MT_BSZCLUSTER_YELLOW",
	"MT_BSZCLUSTER_ORANGE",
	"MT_BSZBUSH_RED",
	"MT_BSZBUSH_PURPLE",
	"MT_BSZBUSH_BLUE",
	"MT_BSZBUSH_CYAN",
	"MT_BSZBUSH_YELLOW",
	"MT_BSZBUSH_ORANGE",
	"MT_BSZVINE_RED",
	"MT_BSZVINE_PURPLE",
	"MT_BSZVINE_BLUE",
	"MT_BSZVINE_CYAN",
	"MT_BSZVINE_YELLOW",
	"MT_BSZVINE_ORANGE",
	"MT_BSZSHRUB",
	"MT_BSZCLOVER",
	"MT_BSZFISH",
	"MT_BSZSUNFLOWER",
	"MT_DBALL",
	"MT_EGGSTATUE2",
	"MT_GREENORB",
	"MT_YELLOWORB",
	"MT_BLUEORB",
	"MT_BLACKORB",
	"MT_WHITEORB",
	"MT_PITYORB",
	"MT_IVSP",
	"MT_SUPERSPARK",
	"MT_BIRD",
	"MT_BUNNY",
	"MT_MOUSE",
	"MT_CHICKEN",
	"MT_COW",
	"MT_REDBIRD",
	"MT_RAIN",
	"MT_SNOWFLAKE",
	"MT_SPLISH",
	"MT_SMOKE",
	"MT_SMALLBUBBLE",
	"MT_MEDIUMBUBBLE",
	"MT_EXTRALARGEBUBBLE",
	"MT_TFOG",
	"MT_SEED",
	"MT_PARTICLE",
	"MT_PARTICLEGEN",
	"MT_SCORE",
	"MT_DROWNNUMBERS",
	"MT_GOTEMERALD",
	"MT_TAG",
	"MT_GOTFLAG",
	"MT_GOTFLAG2",
	"MT_AWATERA",
	"MT_AWATERB",
	"MT_AWATERC",
	"MT_AWATERD",
	"MT_AWATERE",
	"MT_AWATERF",
	"MT_AWATERG",
	"MT_AWATERH",
	"MT_RANDOMAMBIENT",
	"MT_RANDOMAMBIENT2",
	"MT_REDRING",
	"MT_BOUNCERING",
	"MT_RAILRING",
	"MT_INFINITYRING",
	"MT_AUTOMATICRING",
	"MT_EXPLOSIONRING",
	"MT_SCATTERRING",
	"MT_GRENADERING",
	"MT_BOUNCEPICKUP",
	"MT_RAILPICKUP",
	"MT_AUTOPICKUP",
	"MT_EXPLODEPICKUP",
	"MT_SCATTERPICKUP",
	"MT_GRENADEPICKUP",
	"MT_THROWNBOUNCE",
	"MT_THROWNINFINITY",
	"MT_THROWNAUTOMATIC",
	"MT_THROWNSCATTER",
	"MT_THROWNEXPLOSION",
	"MT_THROWNGRENADE",
	"MT_COIN",
	"MT_FLINGCOIN",
	"MT_GOOMBA",
	"MT_BLUEGOOMBA",
	"MT_FIREFLOWER",
	"MT_FIREBALL",
	"MT_SHELL",
	"MT_PUMA",
	"MT_HAMMER",
	"MT_KOOPA",
	"MT_KOOPAFLAME",
	"MT_AXE",
	"MT_MARIOBUSH1",
	"MT_MARIOBUSH2",
	"MT_TOAD",
	"MT_AXIS",
	"MT_AXISTRANSFER",
	"MT_AXISTRANSFERLINE",
	"MT_NIGHTSDRONE",
	"MT_NIGHTSGOAL",
	"MT_NIGHTSCHAR",
	"MT_NIGHTSPARKLE",
	"MT_NIGHTSLOOPHELPER",
	"MT_NIGHTSBUMPER",
	"MT_HOOP",
	"MT_HOOPCOLLIDE",
	"MT_HOOPCENTER",
	"MT_NIGHTSCORE",
	"MT_NIGHTSWING",
	"MT_NIGHTSSUPERLOOP",
	"MT_NIGHTSDRILLREFILL",
	"MT_NIGHTSHELPER",
	"MT_NIGHTSEXTRATIME",
	"MT_NIGHTSLINKFREEZE",
	"MT_EGGCAPSULE",
	"MT_NIGHTOPIANHELPER",
	"MT_TELEPORTMAN",
	"MT_ALTVIEWMAN",
	"MT_CRUMBLEOBJ",
	"MT_TUBEWAYPOINT",
	"MT_PUSH",
	"MT_PULL",
	"MT_GHOST",
	"MT_OVERLAY",
	"MT_POLYANCHOR",
	"MT_POLYSPAWN",
	"MT_POLYSPAWNCRUSH",
	"MT_SKYBOX",
	"MT_SPARK",
	"MT_EXPLODE",
	"MT_UWEXPLODE",
	"MT_ROCKSPAWNER",
	"MT_FALLINGROCK",
	"MT_ROCKCRUMBLE1",
	"MT_ROCKCRUMBLE2",
	"MT_ROCKCRUMBLE3",
	"MT_ROCKCRUMBLE4",
	"MT_ROCKCRUMBLE5",
	"MT_ROCKCRUMBLE6",
	"MT_ROCKCRUMBLE7",
	"MT_ROCKCRUMBLE8",
	"MT_ROCKCRUMBLE9",
	"MT_ROCKCRUMBLE10",
	"MT_ROCKCRUMBLE11",
	"MT_ROCKCRUMBLE12",
	"MT_ROCKCRUMBLE13",
	"MT_ROCKCRUMBLE14",
	"MT_ROCKCRUMBLE15",
	"MT_ROCKCRUMBLE16",
	"MT_SRB1_CRAWLA",
	"MT_SRB1_BAT",
	"MT_SRB1_ROBOFISH",
	"MT_SRB1_VOLCANOGUY",
	"MT_SRB1_HOPPY",
	"MT_SRB1_HOPPYWATER",
	"MT_SRB1_HOPPYSKYLAB",
	"MT_SRB1_MMZFLYING",
	"MT_SRB1_UFO",
	"MT_SRB1_GRAYBOT",
	"MT_SRB1_ROBOTOPOLIS",
	"MT_SRB1_RBZBUZZ",
	"MT_SRB1_RBZSPIKES",
	"MT_SRB1_METALSONIC",
	"MT_SRB1_GOLDBOT",
	"MT_SRB1_GENREX",
	"MT_GRAYSPRING",
	"MT_INVISSPRING",
	"MT_BLUEDIAG",
	"MT_RANDOMITEM",
	"MT_RANDOMITEMPOP",
	"MT_FLOATINGITEM",
	"MT_SIGNSPARKLE",
	"MT_FASTLINE",
	"MT_FASTDUST",
	"MT_BOOSTFLAME",
	"MT_BOOSTSMOKE",
	"MT_SNEAKERTRAIL",
	"MT_AIZDRIFTSTRAT",
	"MT_SPARKLETRAIL",
	"MT_INVULNFLASH",
	"MT_WIPEOUTTRAIL",
	"MT_DRIFTSPARK",
	"MT_BRAKEDRIFT",
	"MT_DRIFTDUST",
	"MT_ROCKETSNEAKER",
	"MT_EGGMANITEM",
	"MT_EGGMANITEM_SHIELD",
	"MT_BANANA",
	"MT_BANANA_SHIELD",
	"MT_ORBINAUT",
	"MT_ORBINAUT_SHIELD",
	"MT_JAWZ",
	"MT_JAWZ_DUD",
	"MT_JAWZ_SHIELD",
	"MT_PLAYERRETICULE",
	"MT_SSMINE_SHIELD",
	"MT_SSMINE",
	"MT_MINEEXPLOSION",
	"MT_MINEEXPLOSIONSOUND",
	"MT_SMOLDERING",
	"MT_BOOMEXPLODE",
	"MT_BOOMPARTICLE",
	"MT_BALLHOG",
	"MT_BALLHOGBOOM",
	"MT_SPB",
	"MT_SPBEXPLOSION",
	"MT_THUNDERSHIELD",
	"MT_SINK",
	"MT_SINK_SHIELD",
	"MT_SINKTRAIL",
	"MT_BATTLEBUMPER",
	"MT_DEZLASER",
	"MT_WAYPOINT",
	"MT_RANDOMAUDIENCE",
	"MT_FLAYM",
	"MT_DEVIL",
	"MT_ANGEL",
	"MT_PALMTREE",
	"MT_FLAG",
	"MT_HEDGEHOG",
	"MT_BUSH1",
	"MT_TWEE",
	"MT_HYDRANT",
	"MT_BIGPUMA",
	"MT_APPLE",
	"MT_DOOD_FLOWER1",
	"MT_DOOD_FLOWER2",
	"MT_DOOD_FLOWER3",
	"MT_DOOD_FLOWER4",
	"MT_DOOD_BOX",
	"MT_DOOD_BALLOON",
	"MT_BIGRING",
	"MT_SNES_DONUTBUSH1",
	"MT_SNES_DONUTBUSH2",
	"MT_SNES_DONUTBUSH3",
	"MT_GBA_BOO",
	"MT_BUZZBOMBER",
	"MT_CHOMPER",
	"MT_PALMTREE2",
	"MT_PURPLEFLOWER1",
	"MT_PURPLEFLOWER2",
	"MT_YELLOWFLOWER1",
	"MT_YELLOWFLOWER2",
	"MT_PLANT2",
	"MT_PLANT3",
	"MT_PLANT4",
	"MT_SKULL",
	"MT_PHANTREE",
	"MT_FLYINGGARG",
	"MT_LAMPPOST",
	"MT_MOSSYTREE",
	"MT_SHADOW",
	"MT_BUMP",
	"MT_FLINGENERGY",
	"MT_ITEMCLASH",
	"MT_FIREDITEM",
	"MT_INSTASHIELDA",
	"MT_INSTASHIELDB",
	"MT_PLAYERARROW",
	"MT_PLAYERWANTED",
	"MT_KARMAHITBOX",
	"MT_KARMAWHEEL",
	"MT_BATTLEPOINT",
	"MT_FZEROBOOM",
	"MT_SONICBUSH",
	"MT_FLAMEPARTICLE",
	"MT_MARBLETORCH",
	"MT_MARBLELIGHT",
	"MT_MARBLEBURNER",
	"MT_CDUFO",
	"MT_RUSTYLAMP_ORANGE",
	"MT_RUSTYCHAIN",
	"MT_BALLOON",
	"MT_PETSMOKER",
	"MT_PETSMOKE",
	"MT_VVVAPE",
	"MT_HTZTREE",
	"MT_HTZBUSH",
	"MT_SGVINE1",
	"MT_SGVINE2",
	"MT_SGVINE3",
	"MT_PGTREE",
	"MT_PGFLOWER1",
	"MT_PGFLOWER2",
	"MT_PGFLOWER3",
	"MT_PGBUSH",
	"MT_DHPILLAR",
	"MT_SPOTLIGHT",
	"MT_RANDOMSHADOW",
	"MT_ROAMINGSHADOW",
	"MT_MAYONAKAARROW",
	"MT_REAPERWAYPOINT",
	"MT_REAPER",
	"MT_MEMENTOSTP",
	"MT_MEMENTOSPARTICLE",
	"MT_JACKINTHEBOX",
	"MT_CDMOON",
	"MT_CDBUSH",
	"MT_CDTREEA",
	"MT_CDTREEB",
	"MT_PINETREE",
	"MT_PINETREE_SIDE",
	"MT_EZZPROPELLER",
	"MT_EZZPROPELLER_BLADE",
	"MT_DP_PALMTREE",
	"MT_AAZTREE_HELPER",
	"MT_AAZTREE_SEG",
	"MT_AAZTREE_COCONUT",
	"MT_AAZTREE_LEAF",
	"MT_BBZDUST",
	"MT_FROGGER",
	"MT_FROGTONGUE",
	"MT_FROGTONGUE_JOINT",
	"MT_ROBRA",
	"MT_ROBRA_HEAD",
	"MT_ROBRA_JOINT",
	"MT_BLUEROBRA",
	"MT_BLUEROBRA_HEAD",
	"MT_BLUEROBRA_JOINT",
	"MT_EERIEFOG",
	"MT_EERIEFOGGEN",
	"MT_SMK_PIPE",
	"MT_SMK_MOLESPAWNER",
	"MT_SMK_MOLE",
	"MT_SMK_THWOMP",
	"MT_SMK_SNOWBALL",
	"MT_SMK_ICEBLOCK",
	"MT_SMK_ICEBLOCK_SIDE",
	"MT_SMK_ICEBLOCK_DEBRIS",
	"MT_BLUEFIRE",
	"MT_GREENFIRE",
	"MT_REGALCHEST",
	"MT_CHIMERASTATUE",
	"MT_DRAGONSTATUE",
	"MT_LIZARDMANSTATUE",
	"MT_PEGASUSSTATUE",
	"MT_ZELDAFIRE",
	"MT_GANBARETHING",
	"MT_GANBAREDUCK",
	"MT_GANBARETREE",
	"MT_MONOKUMA",
	"MT_REDZELDAFIRE",
	"MT_BOWLINGPIN",
	"MT_MERRYAMBIENCE",
	"MT_TWINKLECARTAMBIENCE",
	"MT_EXPLODINGBARREL",
	"MT_MERRYHORSE",
	"MT_BLUEFRUIT",
	"MT_ORANGEFRUIT",
	"MT_REDFRUIT",
	"MT_PINKFRUIT",
	"MT_ADVENTURESPIKEA",
	"MT_ADVENTURESPIKEB",
	"MT_ADVENTURESPIKEC",
	"MT_BOOSTPROMPT",
	"MT_BOOSTOFF",
	"MT_BOOSTON",
	"MT_ARIDTOAD",
	"MT_LIZARDMAN",
	"MT_LIONMAN",
	"MT_OPULENCE_PALMTREE",
	"MT_OPULENCE_FERN",
	"MT_TUMBLEGEM",
	"MT_TUMBLECOIN",
	"MT_KARMAFIREWORK",
	"MT_NAMECHECK",
}

local stats = {
	[0] = "S_NULL",
	"S_UNKNOWN",
	"S_INVISIBLE",
	"S_SPAWNSTATE",
	"S_SEESTATE",
	"S_MELEESTATE",
	"S_MISSILESTATE",
	"S_DEATHSTATE",
	"S_XDEATHSTATE",
	"S_RAISESTATE",
	"S_THOK",
	"S_KART_STND1",
	"S_KART_STND2",
	"S_KART_STND1_L",
	"S_KART_STND2_L",
	"S_KART_STND1_R",
	"S_KART_STND2_R",
	"S_KART_WALK1",
	"S_KART_WALK2",
	"S_KART_WALK1_L",
	"S_KART_WALK2_L",
	"S_KART_WALK1_R",
	"S_KART_WALK2_R",
	"S_KART_RUN1",
	"S_KART_RUN2",
	"S_KART_RUN1_L",
	"S_KART_RUN2_L",
	"S_KART_RUN1_R",
	"S_KART_RUN2_R",
	"S_KART_DRIFT1_L",
	"S_KART_DRIFT2_L",
	"S_KART_DRIFT1_R",
	"S_KART_DRIFT2_R",
	"S_KART_SPIN",
	"S_KART_PAIN",
	"S_KART_SQUISH",
	"S_OBJPLACE_DUMMY",
	"S_PLAY_BOX1",
	"S_PLAY_BOX2",
	"S_PLAY_ICON1",
	"S_PLAY_ICON2",
	"S_PLAY_ICON3",
	"S_PLAY_SIGN",
	"S_POSS_STND",
	"S_POSS_RUN1",
	"S_POSS_RUN2",
	"S_POSS_RUN3",
	"S_POSS_RUN4",
	"S_POSS_RUN5",
	"S_POSS_RUN6",
	"S_SPOS_STND",
	"S_SPOS_RUN1",
	"S_SPOS_RUN2",
	"S_SPOS_RUN3",
	"S_SPOS_RUN4",
	"S_SPOS_RUN5",
	"S_SPOS_RUN6",
	"S_FISH1",
	"S_FISH2",
	"S_FISH3",
	"S_FISH4",
	"S_BUZZLOOK1",
	"S_BUZZLOOK2",
	"S_BUZZFLY1",
	"S_BUZZFLY2",
	"S_RBUZZLOOK1",
	"S_RBUZZLOOK2",
	"S_RBUZZFLY1",
	"S_RBUZZFLY2",
	"S_BBUZZFLY1",
	"S_BBUZZFLY2",
	"S_JETBLOOK1",
	"S_JETBLOOK2",
	"S_JETBZOOM1",
	"S_JETBZOOM2",
	"S_JETGLOOK1",
	"S_JETGLOOK2",
	"S_JETGZOOM1",
	"S_JETGZOOM2",
	"S_JETGSHOOT1",
	"S_JETGSHOOT2",
	"S_CCOMMAND1",
	"S_CCOMMAND2",
	"S_CCOMMAND3",
	"S_CCOMMAND4",
	"S_DETON1",
	"S_DETON2",
	"S_DETON3",
	"S_DETON4",
	"S_DETON5",
	"S_DETON6",
	"S_DETON7",
	"S_DETON8",
	"S_DETON9",
	"S_DETON10",
	"S_DETON11",
	"S_DETON12",
	"S_DETON13",
	"S_DETON14",
	"S_DETON15",
	"S_DETON16",
	"S_SKIM1",
	"S_SKIM2",
	"S_SKIM3",
	"S_SKIM4",
	"S_TURRET",
	"S_TURRETFIRE",
	"S_TURRETSHOCK1",
	"S_TURRETSHOCK2",
	"S_TURRETSHOCK3",
	"S_TURRETSHOCK4",
	"S_TURRETSHOCK5",
	"S_TURRETSHOCK6",
	"S_TURRETSHOCK7",
	"S_TURRETSHOCK8",
	"S_TURRETSHOCK9",
	"S_TURRETLOOK",
	"S_TURRETSEE",
	"S_TURRETPOPUP1",
	"S_TURRETPOPUP2",
	"S_TURRETPOPUP3",
	"S_TURRETPOPUP4",
	"S_TURRETPOPUP5",
	"S_TURRETPOPUP6",
	"S_TURRETPOPUP7",
	"S_TURRETPOPUP8",
	"S_TURRETSHOOT",
	"S_TURRETPOPDOWN1",
	"S_TURRETPOPDOWN2",
	"S_TURRETPOPDOWN3",
	"S_TURRETPOPDOWN4",
	"S_TURRETPOPDOWN5",
	"S_TURRETPOPDOWN6",
	"S_TURRETPOPDOWN7",
	"S_TURRETPOPDOWN8",
	"S_SHARP_ROAM1",
	"S_SHARP_ROAM2",
	"S_SHARP_AIM1",
	"S_SHARP_AIM2",
	"S_SHARP_AIM3",
	"S_SHARP_AIM4",
	"S_SHARP_SPIN",
	"S_JETJAW_ROAM1",
	"S_JETJAW_ROAM2",
	"S_JETJAW_ROAM3",
	"S_JETJAW_ROAM4",
	"S_JETJAW_ROAM5",
	"S_JETJAW_ROAM6",
	"S_JETJAW_ROAM7",
	"S_JETJAW_ROAM8",
	"S_JETJAW_CHOMP1",
	"S_JETJAW_CHOMP2",
	"S_JETJAW_CHOMP3",
	"S_JETJAW_CHOMP4",
	"S_JETJAW_CHOMP5",
	"S_JETJAW_CHOMP6",
	"S_JETJAW_CHOMP7",
	"S_JETJAW_CHOMP8",
	"S_JETJAW_CHOMP9",
	"S_JETJAW_CHOMP10",
	"S_JETJAW_CHOMP11",
	"S_JETJAW_CHOMP12",
	"S_JETJAW_CHOMP13",
	"S_JETJAW_CHOMP14",
	"S_JETJAW_CHOMP15",
	"S_JETJAW_CHOMP16",
	"S_SNAILER1",
	"S_VULTURE_STND",
	"S_VULTURE_VTOL1",
	"S_VULTURE_VTOL2",
	"S_VULTURE_VTOL3",
	"S_VULTURE_VTOL4",
	"S_VULTURE_ZOOM1",
	"S_VULTURE_ZOOM2",
	"S_VULTURE_ZOOM3",
	"S_VULTURE_ZOOM4",
	"S_VULTURE_ZOOM5",
	"S_POINTY1",
	"S_POINTYBALL1",
	"S_ROBOHOOD_LOOK",
	"S_ROBOHOOD_STND",
	"S_ROBOHOOD_SHOOT",
	"S_ROBOHOOD_JUMP",
	"S_ROBOHOOD_JUMP2",
	"S_ROBOHOOD_FALL",
	"S_FACESTABBER_STND1",
	"S_FACESTABBER_STND2",
	"S_FACESTABBER_STND3",
	"S_FACESTABBER_STND4",
	"S_FACESTABBER_STND5",
	"S_FACESTABBER_STND6",
	"S_FACESTABBER_CHARGE1",
	"S_FACESTABBER_CHARGE2",
	"S_FACESTABBER_CHARGE3",
	"S_FACESTABBER_CHARGE4",
	"S_EGGGUARD_STND",
	"S_EGGGUARD_WALK1",
	"S_EGGGUARD_WALK2",
	"S_EGGGUARD_WALK3",
	"S_EGGGUARD_WALK4",
	"S_EGGGUARD_MAD1",
	"S_EGGGUARD_MAD2",
	"S_EGGGUARD_MAD3",
	"S_EGGGUARD_RUN1",
	"S_EGGGUARD_RUN2",
	"S_EGGGUARD_RUN3",
	"S_EGGGUARD_RUN4",
	"S_EGGSHIELD",
	"S_GSNAPPER_STND",
	"S_GSNAPPER1",
	"S_GSNAPPER2",
	"S_GSNAPPER3",
	"S_GSNAPPER4",
	"S_MINUS_STND",
	"S_MINUS_DIGGING",
	"S_MINUS_POPUP",
	"S_MINUS_UPWARD1",
	"S_MINUS_UPWARD2",
	"S_MINUS_UPWARD3",
	"S_MINUS_UPWARD4",
	"S_MINUS_UPWARD5",
	"S_MINUS_UPWARD6",
	"S_MINUS_UPWARD7",
	"S_MINUS_UPWARD8",
	"S_MINUS_DOWNWARD1",
	"S_MINUS_DOWNWARD2",
	"S_MINUS_DOWNWARD3",
	"S_MINUS_DOWNWARD4",
	"S_MINUS_DOWNWARD5",
	"S_MINUS_DOWNWARD6",
	"S_MINUS_DOWNWARD7",
	"S_MINUS_DOWNWARD8",
	"S_SSHELL_STND",
	"S_SSHELL_RUN1",
	"S_SSHELL_RUN2",
	"S_SSHELL_RUN3",
	"S_SSHELL_RUN4",
	"S_SSHELL_SPRING1",
	"S_SSHELL_SPRING2",
	"S_SSHELL_SPRING3",
	"S_SSHELL_SPRING4",
	"S_YSHELL_STND",
	"S_YSHELL_RUN1",
	"S_YSHELL_RUN2",
	"S_YSHELL_RUN3",
	"S_YSHELL_RUN4",
	"S_YSHELL_SPRING1",
	"S_YSHELL_SPRING2",
	"S_YSHELL_SPRING3",
	"S_YSHELL_SPRING4",
	"S_UNIDUS_STND",
	"S_UNIDUS_RUN",
	"S_UNIDUS_BALL",
	"S_BPLD1",
	"S_BPLD2",
	"S_BPLD3",
	"S_BPLD4",
	"S_BPLD5",
	"S_BPLD6",
	"S_BPLD7",
	"S_SONIC3KBOSSEXPLOSION1",
	"S_SONIC3KBOSSEXPLOSION2",
	"S_SONIC3KBOSSEXPLOSION3",
	"S_SONIC3KBOSSEXPLOSION4",
	"S_SONIC3KBOSSEXPLOSION5",
	"S_SONIC3KBOSSEXPLOSION6",
	"S_JETFUME1",
	"S_JETFUME2",
	"S_EGGMOBILE_STND",
	"S_EGGMOBILE_LATK1",
	"S_EGGMOBILE_LATK2",
	"S_EGGMOBILE_LATK3",
	"S_EGGMOBILE_LATK4",
	"S_EGGMOBILE_LATK5",
	"S_EGGMOBILE_LATK6",
	"S_EGGMOBILE_LATK7",
	"S_EGGMOBILE_LATK8",
	"S_EGGMOBILE_LATK9",
	"S_EGGMOBILE_LATK10",
	"S_EGGMOBILE_RATK1",
	"S_EGGMOBILE_RATK2",
	"S_EGGMOBILE_RATK3",
	"S_EGGMOBILE_RATK4",
	"S_EGGMOBILE_RATK5",
	"S_EGGMOBILE_RATK6",
	"S_EGGMOBILE_RATK7",
	"S_EGGMOBILE_RATK8",
	"S_EGGMOBILE_RATK9",
	"S_EGGMOBILE_RATK10",
	"S_EGGMOBILE_PANIC1",
	"S_EGGMOBILE_PANIC2",
	"S_EGGMOBILE_PANIC3",
	"S_EGGMOBILE_PANIC4",
	"S_EGGMOBILE_PANIC5",
	"S_EGGMOBILE_PANIC6",
	"S_EGGMOBILE_PANIC7",
	"S_EGGMOBILE_PANIC8",
	"S_EGGMOBILE_PANIC9",
	"S_EGGMOBILE_PANIC10",
	"S_EGGMOBILE_PAIN",
	"S_EGGMOBILE_PAIN2",
	"S_EGGMOBILE_DIE1",
	"S_EGGMOBILE_DIE2",
	"S_EGGMOBILE_DIE3",
	"S_EGGMOBILE_DIE4",
	"S_EGGMOBILE_DIE5",
	"S_EGGMOBILE_DIE6",
	"S_EGGMOBILE_DIE7",
	"S_EGGMOBILE_DIE8",
	"S_EGGMOBILE_DIE9",
	"S_EGGMOBILE_DIE10",
	"S_EGGMOBILE_DIE11",
	"S_EGGMOBILE_DIE12",
	"S_EGGMOBILE_DIE13",
	"S_EGGMOBILE_DIE14",
	"S_EGGMOBILE_FLEE1",
	"S_EGGMOBILE_FLEE2",
	"S_EGGMOBILE_BALL",
	"S_EGGMOBILE_TARGET",
	"S_EGGMOBILE2_STND",
	"S_EGGMOBILE2_POGO1",
	"S_EGGMOBILE2_POGO2",
	"S_EGGMOBILE2_POGO3",
	"S_EGGMOBILE2_POGO4",
	"S_EGGMOBILE2_POGO5",
	"S_EGGMOBILE2_POGO6",
	"S_EGGMOBILE2_POGO7",
	"S_EGGMOBILE2_PAIN",
	"S_EGGMOBILE2_PAIN2",
	"S_EGGMOBILE2_DIE1",
	"S_EGGMOBILE2_DIE2",
	"S_EGGMOBILE2_DIE3",
	"S_EGGMOBILE2_DIE4",
	"S_EGGMOBILE2_DIE5",
	"S_EGGMOBILE2_DIE6",
	"S_EGGMOBILE2_DIE7",
	"S_EGGMOBILE2_DIE8",
	"S_EGGMOBILE2_DIE9",
	"S_EGGMOBILE2_DIE10",
	"S_EGGMOBILE2_DIE11",
	"S_EGGMOBILE2_DIE12",
	"S_EGGMOBILE2_DIE13",
	"S_EGGMOBILE2_DIE14",
	"S_EGGMOBILE2_FLEE1",
	"S_EGGMOBILE2_FLEE2",
	"S_BOSSTANK1",
	"S_BOSSTANK2",
	"S_BOSSSPIGOT",
	"S_GOOP1",
	"S_GOOP2",
	"S_GOOP3",
	"S_EGGMOBILE3_STND",
	"S_EGGMOBILE3_ATK1",
	"S_EGGMOBILE3_ATK2",
	"S_EGGMOBILE3_ATK3A",
	"S_EGGMOBILE3_ATK3B",
	"S_EGGMOBILE3_ATK3C",
	"S_EGGMOBILE3_ATK3D",
	"S_EGGMOBILE3_ATK4",
	"S_EGGMOBILE3_ATK5",
	"S_EGGMOBILE3_LAUGH1",
	"S_EGGMOBILE3_LAUGH2",
	"S_EGGMOBILE3_LAUGH3",
	"S_EGGMOBILE3_LAUGH4",
	"S_EGGMOBILE3_LAUGH5",
	"S_EGGMOBILE3_LAUGH6",
	"S_EGGMOBILE3_LAUGH7",
	"S_EGGMOBILE3_LAUGH8",
	"S_EGGMOBILE3_LAUGH9",
	"S_EGGMOBILE3_LAUGH10",
	"S_EGGMOBILE3_LAUGH11",
	"S_EGGMOBILE3_LAUGH12",
	"S_EGGMOBILE3_LAUGH13",
	"S_EGGMOBILE3_LAUGH14",
	"S_EGGMOBILE3_LAUGH15",
	"S_EGGMOBILE3_LAUGH16",
	"S_EGGMOBILE3_LAUGH17",
	"S_EGGMOBILE3_LAUGH18",
	"S_EGGMOBILE3_LAUGH19",
	"S_EGGMOBILE3_LAUGH20",
	"S_EGGMOBILE3_PAIN",
	"S_EGGMOBILE3_PAIN2",
	"S_EGGMOBILE3_DIE1",
	"S_EGGMOBILE3_DIE2",
	"S_EGGMOBILE3_DIE3",
	"S_EGGMOBILE3_DIE4",
	"S_EGGMOBILE3_DIE5",
	"S_EGGMOBILE3_DIE6",
	"S_EGGMOBILE3_DIE7",
	"S_EGGMOBILE3_DIE8",
	"S_EGGMOBILE3_DIE9",
	"S_EGGMOBILE3_DIE10",
	"S_EGGMOBILE3_DIE11",
	"S_EGGMOBILE3_DIE12",
	"S_EGGMOBILE3_DIE13",
	"S_EGGMOBILE3_DIE14",
	"S_EGGMOBILE3_FLEE1",
	"S_EGGMOBILE3_FLEE2",
	"S_PROPELLER1",
	"S_PROPELLER2",
	"S_PROPELLER3",
	"S_PROPELLER4",
	"S_PROPELLER5",
	"S_PROPELLER6",
	"S_PROPELLER7",
	"S_FAKEMOBILE_INIT",
	"S_FAKEMOBILE",
	"S_FAKEMOBILE_ATK1",
	"S_FAKEMOBILE_ATK2",
	"S_FAKEMOBILE_ATK3A",
	"S_FAKEMOBILE_ATK3B",
	"S_FAKEMOBILE_ATK3C",
	"S_FAKEMOBILE_ATK3D",
	"S_FAKEMOBILE_ATK4",
	"S_FAKEMOBILE_ATK5",
	"S_EGGMOBILE4_STND",
	"S_EGGMOBILE4_LATK1",
	"S_EGGMOBILE4_LATK2",
	"S_EGGMOBILE4_LATK3",
	"S_EGGMOBILE4_LATK4",
	"S_EGGMOBILE4_LATK5",
	"S_EGGMOBILE4_LATK6",
	"S_EGGMOBILE4_RATK1",
	"S_EGGMOBILE4_RATK2",
	"S_EGGMOBILE4_RATK3",
	"S_EGGMOBILE4_RATK4",
	"S_EGGMOBILE4_RATK5",
	"S_EGGMOBILE4_RATK6",
	"S_EGGMOBILE4_RAISE1",
	"S_EGGMOBILE4_RAISE2",
	"S_EGGMOBILE4_RAISE3",
	"S_EGGMOBILE4_RAISE4",
	"S_EGGMOBILE4_RAISE5",
	"S_EGGMOBILE4_RAISE6",
	"S_EGGMOBILE4_RAISE7",
	"S_EGGMOBILE4_RAISE8",
	"S_EGGMOBILE4_RAISE9",
	"S_EGGMOBILE4_RAISE10",
	"S_EGGMOBILE4_PAIN",
	"S_EGGMOBILE4_DIE1",
	"S_EGGMOBILE4_DIE2",
	"S_EGGMOBILE4_DIE3",
	"S_EGGMOBILE4_DIE4",
	"S_EGGMOBILE4_DIE5",
	"S_EGGMOBILE4_DIE6",
	"S_EGGMOBILE4_DIE7",
	"S_EGGMOBILE4_DIE8",
	"S_EGGMOBILE4_DIE9",
	"S_EGGMOBILE4_DIE10",
	"S_EGGMOBILE4_DIE11",
	"S_EGGMOBILE4_DIE12",
	"S_EGGMOBILE4_DIE13",
	"S_EGGMOBILE4_DIE14",
	"S_EGGMOBILE4_FLEE1",
	"S_EGGMOBILE4_FLEE2",
	"S_EGGMOBILE4_MACE",
	"S_JETFLAME1",
	"S_JETFLAME2",
	"S_BLACKEGG_STND",
	"S_BLACKEGG_STND2",
	"S_BLACKEGG_WALK1",
	"S_BLACKEGG_WALK2",
	"S_BLACKEGG_WALK3",
	"S_BLACKEGG_WALK4",
	"S_BLACKEGG_WALK5",
	"S_BLACKEGG_WALK6",
	"S_BLACKEGG_SHOOT1",
	"S_BLACKEGG_SHOOT2",
	"S_BLACKEGG_PAIN1",
	"S_BLACKEGG_PAIN2",
	"S_BLACKEGG_PAIN3",
	"S_BLACKEGG_PAIN4",
	"S_BLACKEGG_PAIN5",
	"S_BLACKEGG_PAIN6",
	"S_BLACKEGG_PAIN7",
	"S_BLACKEGG_PAIN8",
	"S_BLACKEGG_PAIN9",
	"S_BLACKEGG_PAIN10",
	"S_BLACKEGG_PAIN11",
	"S_BLACKEGG_PAIN12",
	"S_BLACKEGG_PAIN13",
	"S_BLACKEGG_PAIN14",
	"S_BLACKEGG_PAIN15",
	"S_BLACKEGG_PAIN16",
	"S_BLACKEGG_PAIN17",
	"S_BLACKEGG_PAIN18",
	"S_BLACKEGG_PAIN19",
	"S_BLACKEGG_PAIN20",
	"S_BLACKEGG_PAIN21",
	"S_BLACKEGG_PAIN22",
	"S_BLACKEGG_PAIN23",
	"S_BLACKEGG_PAIN24",
	"S_BLACKEGG_PAIN25",
	"S_BLACKEGG_PAIN26",
	"S_BLACKEGG_PAIN27",
	"S_BLACKEGG_PAIN28",
	"S_BLACKEGG_PAIN29",
	"S_BLACKEGG_PAIN30",
	"S_BLACKEGG_PAIN31",
	"S_BLACKEGG_PAIN32",
	"S_BLACKEGG_PAIN33",
	"S_BLACKEGG_PAIN34",
	"S_BLACKEGG_PAIN35",
	"S_BLACKEGG_HITFACE1",
	"S_BLACKEGG_HITFACE2",
	"S_BLACKEGG_HITFACE3",
	"S_BLACKEGG_HITFACE4",
	"S_BLACKEGG_DIE1",
	"S_BLACKEGG_DIE2",
	"S_BLACKEGG_DIE3",
	"S_BLACKEGG_DIE4",
	"S_BLACKEGG_DIE5",
	"S_BLACKEGG_MISSILE1",
	"S_BLACKEGG_MISSILE2",
	"S_BLACKEGG_MISSILE3",
	"S_BLACKEGG_GOOP",
	"S_BLACKEGG_JUMP1",
	"S_BLACKEGG_JUMP2",
	"S_BLACKEGG_DESTROYPLAT1",
	"S_BLACKEGG_DESTROYPLAT2",
	"S_BLACKEGG_DESTROYPLAT3",
	"S_BLACKEGG_HELPER",
	"S_BLACKEGG_GOOP1",
	"S_BLACKEGG_GOOP2",
	"S_BLACKEGG_GOOP3",
	"S_BLACKEGG_GOOP4",
	"S_BLACKEGG_GOOP5",
	"S_BLACKEGG_GOOP6",
	"S_BLACKEGG_GOOP7",
	"S_BLACKEGG_MISSILE",
	"S_CYBRAKDEMON_IDLE",
	"S_CYBRAKDEMON_WALK1",
	"S_CYBRAKDEMON_WALK2",
	"S_CYBRAKDEMON_WALK3",
	"S_CYBRAKDEMON_WALK4",
	"S_CYBRAKDEMON_WALK5",
	"S_CYBRAKDEMON_WALK6",
	"S_CYBRAKDEMON_CHOOSE_ATTACK1",
	"S_CYBRAKDEMON_MISSILE_ATTACK1",
	"S_CYBRAKDEMON_MISSILE_ATTACK2",
	"S_CYBRAKDEMON_MISSILE_ATTACK3",
	"S_CYBRAKDEMON_MISSILE_ATTACK4",
	"S_CYBRAKDEMON_MISSILE_ATTACK5",
	"S_CYBRAKDEMON_MISSILE_ATTACK6",
	"S_CYBRAKDEMON_FLAME_ATTACK1",
	"S_CYBRAKDEMON_FLAME_ATTACK2",
	"S_CYBRAKDEMON_FLAME_ATTACK3",
	"S_CYBRAKDEMON_FLAME_ATTACK4",
	"S_CYBRAKDEMON_CHOOSE_ATTACK2",
	"S_CYBRAKDEMON_VILE_ATTACK1",
	"S_CYBRAKDEMON_VILE_ATTACK2",
	"S_CYBRAKDEMON_VILE_ATTACK3",
	"S_CYBRAKDEMON_VILE_ATTACK4",
	"S_CYBRAKDEMON_VILE_ATTACK5",
	"S_CYBRAKDEMON_VILE_ATTACK6",
	"S_CYBRAKDEMON_NAPALM_ATTACK1",
	"S_CYBRAKDEMON_NAPALM_ATTACK2",
	"S_CYBRAKDEMON_NAPALM_ATTACK3",
	"S_CYBRAKDEMON_FINISH_ATTACK",
	"S_CYBRAKDEMON_FINISH_ATTACK2",
	"S_CYBRAKDEMON_PAIN1",
	"S_CYBRAKDEMON_PAIN2",
	"S_CYBRAKDEMON_PAIN3",
	"S_CYBRAKDEMON_DIE1",
	"S_CYBRAKDEMON_DIE2",
	"S_CYBRAKDEMON_DIE3",
	"S_CYBRAKDEMON_DIE4",
	"S_CYBRAKDEMON_DIE5",
	"S_CYBRAKDEMON_DIE6",
	"S_CYBRAKDEMON_DIE7",
	"S_CYBRAKDEMON_DIE8",
	"S_CYBRAKDEMON_DEINVINCIBLERIZE",
	"S_CYBRAKDEMON_INVINCIBLERIZE",
	"S_CYBRAKDEMONMISSILE",
	"S_CYBRAKDEMONMISSILE_EXPLODE1",
	"S_CYBRAKDEMONMISSILE_EXPLODE2",
	"S_CYBRAKDEMONMISSILE_EXPLODE3",
	"S_CYBRAKDEMONFLAMESHOT_FLY1",
	"S_CYBRAKDEMONFLAMESHOT_FLY2",
	"S_CYBRAKDEMONFLAMESHOT_FLY3",
	"S_CYBRAKDEMONFLAMESHOT_DIE",
	"S_CYBRAKDEMONFLAMEREST",
	"S_CYBRAKDEMONELECTRICBARRIER_INIT1",
	"S_CYBRAKDEMONELECTRICBARRIER_INIT2",
	"S_CYBRAKDEMONELECTRICBARRIER_PLAYSOUND",
	"S_CYBRAKDEMONELECTRICBARRIER1",
	"S_CYBRAKDEMONELECTRICBARRIER2",
	"S_CYBRAKDEMONELECTRICBARRIER3",
	"S_CYBRAKDEMONELECTRICBARRIER4",
	"S_CYBRAKDEMONELECTRICBARRIER5",
	"S_CYBRAKDEMONELECTRICBARRIER6",
	"S_CYBRAKDEMONELECTRICBARRIER7",
	"S_CYBRAKDEMONELECTRICBARRIER8",
	"S_CYBRAKDEMONELECTRICBARRIER9",
	"S_CYBRAKDEMONELECTRICBARRIER10",
	"S_CYBRAKDEMONELECTRICBARRIER11",
	"S_CYBRAKDEMONELECTRICBARRIER12",
	"S_CYBRAKDEMONELECTRICBARRIER13",
	"S_CYBRAKDEMONELECTRICBARRIER14",
	"S_CYBRAKDEMONELECTRICBARRIER15",
	"S_CYBRAKDEMONELECTRICBARRIER16",
	"S_CYBRAKDEMONELECTRICBARRIER17",
	"S_CYBRAKDEMONELECTRICBARRIER18",
	"S_CYBRAKDEMONELECTRICBARRIER19",
	"S_CYBRAKDEMONELECTRICBARRIER20",
	"S_CYBRAKDEMONELECTRICBARRIER21",
	"S_CYBRAKDEMONELECTRICBARRIER22",
	"S_CYBRAKDEMONELECTRICBARRIER23",
	"S_CYBRAKDEMONELECTRICBARRIER24",
	"S_CYBRAKDEMONELECTRICBARRIER_DIE1",
	"S_CYBRAKDEMONELECTRICBARRIER_DIE2",
	"S_CYBRAKDEMONELECTRICBARRIER_DIE3",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOMCHECK",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOMSUCCESS",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOMCHOOSE",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOM1",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOM2",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOM3",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOM4",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOM5",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOM6",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOM7",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOM8",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOM9",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOM10",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOM11",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOM12",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOMFAIL",
	"S_CYBRAKDEMONELECTRICBARRIER_SPARK_RANDOMLOOP",
	"S_CYBRAKDEMONELECTRICBARRIER_REVIVE1",
	"S_CYBRAKDEMONELECTRICBARRIER_REVIVE2",
	"S_CYBRAKDEMONELECTRICBARRIER_REVIVE3",
	"S_CYBRAKDEMONTARGETRETICULE1",
	"S_CYBRAKDEMONTARGETRETICULE2",
	"S_CYBRAKDEMONTARGETRETICULE3",
	"S_CYBRAKDEMONTARGETRETICULE4",
	"S_CYBRAKDEMONTARGETRETICULE5",
	"S_CYBRAKDEMONTARGETRETICULE6",
	"S_CYBRAKDEMONTARGETRETICULE7",
	"S_CYBRAKDEMONTARGETRETICULE8",
	"S_CYBRAKDEMONTARGETRETICULE9",
	"S_CYBRAKDEMONTARGETRETICULE10",
	"S_CYBRAKDEMONTARGETRETICULE11",
	"S_CYBRAKDEMONTARGETRETICULE12",
	"S_CYBRAKDEMONTARGETRETICULE13",
	"S_CYBRAKDEMONTARGETRETICULE14",
	"S_CYBRAKDEMONTARGETDOT",
	"S_CYBRAKDEMONNAPALMBOMBLARGE_FLY1",
	"S_CYBRAKDEMONNAPALMBOMBLARGE_FLY2",
	"S_CYBRAKDEMONNAPALMBOMBLARGE_FLY3",
	"S_CYBRAKDEMONNAPALMBOMBLARGE_FLY4",
	"S_CYBRAKDEMONNAPALMBOMBLARGE_DIE1",
	"S_CYBRAKDEMONNAPALMBOMBLARGE_DIE2",
	"S_CYBRAKDEMONNAPALMBOMBLARGE_DIE3",
	"S_CYBRAKDEMONNAPALMBOMBLARGE_DIE4",
	"S_CYBRAKDEMONNAPALMBOMBSMALL",
	"S_CYBRAKDEMONNAPALMBOMBSMALL_DIE1",
	"S_CYBRAKDEMONNAPALMBOMBSMALL_DIE2",
	"S_CYBRAKDEMONNAPALMBOMBSMALL_DIE3",
	"S_CYBRAKDEMONNAPALMBOMBSMALL_DIE4",
	"S_CYBRAKDEMONNAPALMBOMBSMALL_DIE5",
	"S_CYBRAKDEMONNAPALMFLAME_FLY1",
	"S_CYBRAKDEMONNAPALMFLAME_FLY2",
	"S_CYBRAKDEMONNAPALMFLAME_FLY3",
	"S_CYBRAKDEMONNAPALMFLAME_FLY4",
	"S_CYBRAKDEMONNAPALMFLAME_FLY5",
	"S_CYBRAKDEMONNAPALMFLAME_FLY6",
	"S_CYBRAKDEMONNAPALMFLAME_DIE",
	"S_CYBRAKDEMONVILEEXPLOSION1",
	"S_CYBRAKDEMONVILEEXPLOSION2",
	"S_CYBRAKDEMONVILEEXPLOSION3",
	"S_METALSONIC_STAND",
	"S_METALSONIC_WAIT1",
	"S_METALSONIC_WAIT2",
	"S_METALSONIC_WALK1",
	"S_METALSONIC_WALK2",
	"S_METALSONIC_WALK3",
	"S_METALSONIC_WALK4",
	"S_METALSONIC_WALK5",
	"S_METALSONIC_WALK6",
	"S_METALSONIC_WALK7",
	"S_METALSONIC_WALK8",
	"S_METALSONIC_RUN1",
	"S_METALSONIC_RUN2",
	"S_METALSONIC_RUN3",
	"S_METALSONIC_RUN4",
	"S_METALSONIC_FLOAT",
	"S_METALSONIC_VECTOR",
	"S_METALSONIC_STUN",
	"S_METALSONIC_BLOCK",
	"S_METALSONIC_RAISE",
	"S_METALSONIC_GATHER",
	"S_METALSONIC_DASH",
	"S_METALSONIC_BOUNCE",
	"S_METALSONIC_SHOOT",
	"S_METALSONIC_PAIN",
	"S_METALSONIC_DEATH",
	"S_METALSONIC_FLEE1",
	"S_METALSONIC_FLEE2",
	"S_METALSONIC_FLEE3",
	"S_METALSONIC_FLEE4",
	"S_MSSHIELD_F1",
	"S_MSSHIELD_F2",
	"S_MSSHIELD_F3",
	"S_MSSHIELD_F4",
	"S_MSSHIELD_F5",
	"S_MSSHIELD_F6",
	"S_MSSHIELD_F7",
	"S_MSSHIELD_F8",
	"S_MSSHIELD_F9",
	"S_MSSHIELD_F10",
	"S_MSSHIELD_F11",
	"S_MSSHIELD_F12",
	"S_RING",
	"S_BLUEBALL",
	"S_BLUEBALLSPARK",
	"S_GRAVWELLGREEN",
	"S_GRAVWELLGREEN2",
	"S_GRAVWELLGREEN3",
	"S_GRAVWELLRED",
	"S_GRAVWELLRED2",
	"S_GRAVWELLRED3",
	"S_TEAMRING",
	"S_EMMY",
	"S_TOKEN",
	"S_MOVINGTOKEN",
	"S_REDFLAG",
	"S_BLUEFLAG",
	"S_EMBLEM1",
	"S_EMBLEM2",
	"S_EMBLEM3",
	"S_EMBLEM4",
	"S_EMBLEM5",
	"S_EMBLEM6",
	"S_EMBLEM7",
	"S_EMBLEM8",
	"S_EMBLEM9",
	"S_EMBLEM10",
	"S_EMBLEM11",
	"S_EMBLEM12",
	"S_EMBLEM13",
	"S_EMBLEM14",
	"S_EMBLEM15",
	"S_EMBLEM16",
	"S_EMBLEM17",
	"S_EMBLEM18",
	"S_EMBLEM19",
	"S_EMBLEM20",
	"S_EMBLEM21",
	"S_EMBLEM22",
	"S_EMBLEM23",
	"S_EMBLEM24",
	"S_EMBLEM25",
	"S_EMBLEM26",
	"S_CEMG1",
	"S_CEMG2",
	"S_CEMG3",
	"S_CEMG4",
	"S_CEMG5",
	"S_CEMG6",
	"S_CEMG7",
	"S_EMER1",
	"S_FAN",
	"S_FAN2",
	"S_FAN3",
	"S_FAN4",
	"S_FAN5",
	"S_BUBBLES1",
	"S_BUBBLES2",
	"S_SIGN1",
	"S_SIGN2",
	"S_SIGN3",
	"S_SIGN4",
	"S_SIGN5",
	"S_SIGN6",
	"S_SIGN7",
	"S_SIGN8",
	"S_SIGN9",
	"S_SIGN10",
	"S_SIGN11",
	"S_SIGN12",
	"S_SIGN13",
	"S_SIGN14",
	"S_SIGN15",
	"S_SIGN16",
	"S_SIGN17",
	"S_SIGN18",
	"S_SIGN19",
	"S_SIGN20",
	"S_SIGN_END",
	"S_STEAM1",
	"S_STEAM2",
	"S_STEAM3",
	"S_STEAM4",
	"S_STEAM5",
	"S_STEAM6",
	"S_STEAM7",
	"S_STEAM8",
	"S_SPIKEBALL1",
	"S_SPIKEBALL2",
	"S_SPIKEBALL3",
	"S_SPIKEBALL4",
	"S_SPIKEBALL5",
	"S_SPIKEBALL6",
	"S_SPIKEBALL7",
	"S_SPIKEBALL8",
	"S_SPINFIRE1",
	"S_SPINFIRE2",
	"S_SPINFIRE3",
	"S_SPINFIRE4",
	"S_SPINFIRE5",
	"S_SPINFIRE6",
	"S_SPIKE1",
	"S_SPIKE2",
	"S_SPIKE3",
	"S_SPIKE4",
	"S_SPIKE5",
	"S_SPIKE6",
	"S_SPIKED1",
	"S_SPIKED2",
	"S_STARPOST_IDLE",
	"S_STARPOST_FLASH",
	"S_STARPOST_SPIN",
	"S_BIGMINE1",
	"S_BIGMINE2",
	"S_BIGMINE3",
	"S_BIGMINE4",
	"S_BIGMINE5",
	"S_BIGMINE6",
	"S_BIGMINE7",
	"S_BIGMINE8",
	"S_CANNONLAUNCHER1",
	"S_CANNONLAUNCHER2",
	"S_CANNONLAUNCHER3",
	"S_SUPERRINGBOX",
	"S_SUPERRINGBOX1",
	"S_SUPERRINGBOX2",
	"S_SUPERRINGBOX3",
	"S_SUPERRINGBOX4",
	"S_SUPERRINGBOX5",
	"S_SUPERRINGBOX6",
	"S_REDRINGBOX",
	"S_REDRINGBOX1",
	"S_BLUERINGBOX",
	"S_BLUERINGBOX1",
	"S_SHTV",
	"S_SHTV1",
	"S_SHTV2",
	"S_SHTV3",
	"S_SHTV4",
	"S_SHTV5",
	"S_SHTV6",
	"S_PINV",
	"S_PINV1",
	"S_PINV2",
	"S_PINV3",
	"S_PINV4",
	"S_PINV5",
	"S_PINV6",
	"S_PRUP",
	"S_PRUP1",
	"S_PRUP2",
	"S_PRUP3",
	"S_PRUP4",
	"S_PRUP5",
	"S_PRUP6",
	"S_YLTV",
	"S_YLTV1",
	"S_YLTV2",
	"S_YLTV3",
	"S_YLTV4",
	"S_YLTV5",
	"S_YLTV6",
	"S_BLTV1",
	"S_BLTV2",
	"S_BLTV3",
	"S_BLTV4",
	"S_BLTV5",
	"S_BLTV6",
	"S_BLTV7",
	"S_BKTV1",
	"S_BKTV2",
	"S_BKTV3",
	"S_BKTV4",
	"S_BKTV5",
	"S_BKTV6",
	"S_BKTV7",
	"S_WHTV1",
	"S_WHTV2",
	"S_WHTV3",
	"S_WHTV4",
	"S_WHTV5",
	"S_WHTV6",
	"S_WHTV7",
	"S_GRTV",
	"S_GRTV1",
	"S_GRTV2",
	"S_GRTV3",
	"S_GRTV4",
	"S_GRTV5",
	"S_GRTV6",
	"S_PITV1",
	"S_PITV2",
	"S_PITV3",
	"S_PITV4",
	"S_PITV5",
	"S_PITV6",
	"S_PITV7",
	"S_EGGTV1",
	"S_EGGTV2",
	"S_EGGTV3",
	"S_EGGTV4",
	"S_EGGTV5",
	"S_EGGTV6",
	"S_EGGTV7",
	"S_MIXUPBOX1",
	"S_MIXUPBOX2",
	"S_MIXUPBOX3",
	"S_MIXUPBOX4",
	"S_MIXUPBOX5",
	"S_MIXUPBOX6",
	"S_MIXUPBOX7",
	"S_RECYCLETV1",
	"S_RECYCLETV2",
	"S_RECYCLETV3",
	"S_RECYCLETV4",
	"S_RECYCLETV5",
	"S_RECYCLETV6",
	"S_RECYCLETV7",
	"S_RANDOMBOX1",
	"S_RANDOMBOX2",
	"S_RANDOMBOX3",
	"S_GBTV1",
	"S_GBTV2",
	"S_GBTV3",
	"S_GBTV4",
	"S_GBTV5",
	"S_GBTV6",
	"S_GBTV7",
	"S_SCORETVA1",
	"S_SCORETVA2",
	"S_SCORETVA3",
	"S_SCORETVA4",
	"S_SCORETVA5",
	"S_SCORETVA6",
	"S_SCORETVA7",
	"S_SCORETVB1",
	"S_SCORETVB2",
	"S_SCORETVB3",
	"S_SCORETVB4",
	"S_SCORETVB5",
	"S_SCORETVB6",
	"S_SCORETVB7",
	"S_MONITOREXPLOSION1",
	"S_MONITOREXPLOSION2",
	"S_REDMONITOREXPLOSION1",
	"S_REDMONITOREXPLOSION2",
	"S_BLUEMONITOREXPLOSION1",
	"S_BLUEMONITOREXPLOSION2",
	"S_ROCKET",
	"S_LASER",
	"S_TORPEDO",
	"S_ENERGYBALL1",
	"S_ENERGYBALL2",
	"S_MINE1",
	"S_MINE_BOOM1",
	"S_MINE_BOOM2",
	"S_MINE_BOOM3",
	"S_MINE_BOOM4",
	"S_JETBULLET1",
	"S_JETBULLET2",
	"S_TURRETLASER",
	"S_TURRETLASEREXPLODE1",
	"S_TURRETLASEREXPLODE2",
	"S_CANNONBALL1",
	"S_ARROW",
	"S_ARROWUP",
	"S_ARROWDOWN",
	"S_DEMONFIRE1",
	"S_DEMONFIRE2",
	"S_DEMONFIRE3",
	"S_DEMONFIRE4",
	"S_DEMONFIRE5",
	"S_DEMONFIRE6",
	"S_GFZFLOWERA",
	"S_GFZFLOWERA2",
	"S_GFZFLOWERB1",
	"S_GFZFLOWERB2",
	"S_GFZFLOWERC1",
	"S_BERRYBUSH",
	"S_BUSH",
	"S_THZPLANT1",
	"S_THZPLANT2",
	"S_THZPLANT3",
	"S_THZPLANT4",
	"S_ALARM1",
	"S_GARGOYLE",
	"S_SEAWEED1",
	"S_SEAWEED2",
	"S_SEAWEED3",
	"S_SEAWEED4",
	"S_SEAWEED5",
	"S_SEAWEED6",
	"S_DRIPA1",
	"S_DRIPA2",
	"S_DRIPA3",
	"S_DRIPA4",
	"S_DRIPB1",
	"S_DRIPC1",
	"S_DRIPC2",
	"S_CORAL1",
	"S_CORAL2",
	"S_CORAL3",
	"S_BLUECRYSTAL1",
	"S_CEZCHAIN",
	"S_FLAME1",
	"S_FLAME2",
	"S_FLAME3",
	"S_FLAME4",
	"S_EGGSTATUE1",
	"S_SLING1",
	"S_SLING2",
	"S_SMALLMACECHAIN",
	"S_BIGMACECHAIN",
	"S_SMALLMACE",
	"S_BIGMACE",
	"S_CEZFLOWER1",
	"S_BIGTUMBLEWEED",
	"S_BIGTUMBLEWEED_ROLL1",
	"S_BIGTUMBLEWEED_ROLL2",
	"S_BIGTUMBLEWEED_ROLL3",
	"S_BIGTUMBLEWEED_ROLL4",
	"S_BIGTUMBLEWEED_ROLL5",
	"S_BIGTUMBLEWEED_ROLL6",
	"S_BIGTUMBLEWEED_ROLL7",
	"S_BIGTUMBLEWEED_ROLL8",
	"S_LITTLETUMBLEWEED",
	"S_LITTLETUMBLEWEED_ROLL1",
	"S_LITTLETUMBLEWEED_ROLL2",
	"S_LITTLETUMBLEWEED_ROLL3",
	"S_LITTLETUMBLEWEED_ROLL4",
	"S_LITTLETUMBLEWEED_ROLL5",
	"S_LITTLETUMBLEWEED_ROLL6",
	"S_LITTLETUMBLEWEED_ROLL7",
	"S_LITTLETUMBLEWEED_ROLL8",
	"S_CACTI1",
	"S_CACTI2",
	"S_CACTI3",
	"S_CACTI4",
	"S_FLAMEJETSTND",
	"S_FLAMEJETSTART",
	"S_FLAMEJETSTOP",
	"S_FLAMEJETFLAME1",
	"S_FLAMEJETFLAME2",
	"S_FLAMEJETFLAME3",
	"S_FJSPINAXISA1",
	"S_FJSPINAXISA2",
	"S_FJSPINAXISA3",
	"S_FJSPINAXISA4",
	"S_FJSPINAXISA5",
	"S_FJSPINAXISA6",
	"S_FJSPINAXISA7",
	"S_FJSPINAXISA8",
	"S_FJSPINAXISA9",
	"S_FJSPINHELPERA1",
	"S_FJSPINHELPERA2",
	"S_FJSPINHELPERA3",
	"S_FJSPINAXISB1",
	"S_FJSPINAXISB2",
	"S_FJSPINAXISB3",
	"S_FJSPINAXISB4",
	"S_FJSPINAXISB5",
	"S_FJSPINAXISB6",
	"S_FJSPINAXISB7",
	"S_FJSPINAXISB8",
	"S_FJSPINAXISB9",
	"S_FJSPINHELPERB1",
	"S_FJSPINHELPERB2",
	"S_FJSPINHELPERB3",
	"S_FLAMEJETFLAMEB1",
	"S_FLAMEJETFLAMEB2",
	"S_FLAMEJETFLAMEB3",
	"S_FLAMEJETFLAMEB4",
	"S_FLAMEJETFLAMEB5",
	"S_FLAMEJETFLAMEB6",
	"S_TRAPGOYLE",
	"S_TRAPGOYLE_CHECK",
	"S_TRAPGOYLE_FIRE1",
	"S_TRAPGOYLE_FIRE2",
	"S_TRAPGOYLE_FIRE3",
	"S_TRAPGOYLEUP",
	"S_TRAPGOYLEUP_CHECK",
	"S_TRAPGOYLEUP_FIRE1",
	"S_TRAPGOYLEUP_FIRE2",
	"S_TRAPGOYLEUP_FIRE3",
	"S_TRAPGOYLEDOWN",
	"S_TRAPGOYLEDOWN_CHECK",
	"S_TRAPGOYLEDOWN_FIRE1",
	"S_TRAPGOYLEDOWN_FIRE2",
	"S_TRAPGOYLEDOWN_FIRE3",
	"S_TRAPGOYLELONG",
	"S_TRAPGOYLELONG_CHECK",
	"S_TRAPGOYLELONG_FIRE1",
	"S_TRAPGOYLELONG_FIRE2",
	"S_TRAPGOYLELONG_FIRE3",
	"S_TRAPGOYLELONG_FIRE4",
	"S_TRAPGOYLELONG_FIRE5",
	"S_TARGET_IDLE",
	"S_TARGET_HIT1",
	"S_TARGET_HIT2",
	"S_TARGET_RESPAWN",
	"S_TARGET_ALLDONE",
	"S_STG0",
	"S_STG1",
	"S_STG2",
	"S_STG3",
	"S_STG4",
	"S_STG5",
	"S_STG6",
	"S_STG7",
	"S_STG8",
	"S_STG9",
	"S_XMASPOLE",
	"S_CANDYCANE",
	"S_SNOWMAN",
	"S_SNOWMANHAT",
	"S_LAMPPOST1",
	"S_LAMPPOST2",
	"S_HANGSTAR",
	"S_BSZTALLFLOWER_RED",
	"S_BSZTALLFLOWER_PURPLE",
	"S_BSZTALLFLOWER_BLUE",
	"S_BSZTALLFLOWER_CYAN",
	"S_BSZTALLFLOWER_YELLOW",
	"S_BSZTALLFLOWER_ORANGE",
	"S_BSZFLOWER_RED",
	"S_BSZFLOWER_PURPLE",
	"S_BSZFLOWER_BLUE",
	"S_BSZFLOWER_CYAN",
	"S_BSZFLOWER_YELLOW",
	"S_BSZFLOWER_ORANGE",
	"S_BSZSHORTFLOWER_RED",
	"S_BSZSHORTFLOWER_PURPLE",
	"S_BSZSHORTFLOWER_BLUE",
	"S_BSZSHORTFLOWER_CYAN",
	"S_BSZSHORTFLOWER_YELLOW",
	"S_BSZSHORTFLOWER_ORANGE",
	"S_BSZTULIP_RED",
	"S_BSZTULIP_PURPLE",
	"S_BSZTULIP_BLUE",
	"S_BSZTULIP_CYAN",
	"S_BSZTULIP_YELLOW",
	"S_BSZTULIP_ORANGE",
	"S_BSZCLUSTER_RED",
	"S_BSZCLUSTER_PURPLE",
	"S_BSZCLUSTER_BLUE",
	"S_BSZCLUSTER_CYAN",
	"S_BSZCLUSTER_YELLOW",
	"S_BSZCLUSTER_ORANGE",
	"S_BSZBUSH_RED",
	"S_BSZBUSH_PURPLE",
	"S_BSZBUSH_BLUE",
	"S_BSZBUSH_CYAN",
	"S_BSZBUSH_YELLOW",
	"S_BSZBUSH_ORANGE",
	"S_BSZVINE_RED",
	"S_BSZVINE_PURPLE",
	"S_BSZVINE_BLUE",
	"S_BSZVINE_CYAN",
	"S_BSZVINE_YELLOW",
	"S_BSZVINE_ORANGE",
	"S_BSZSHRUB",
	"S_BSZCLOVER",
	"S_BSZFISH",
	"S_BSZSUNFLOWER",
	"S_DBALL1",
	"S_DBALL2",
	"S_DBALL3",
	"S_DBALL4",
	"S_DBALL5",
	"S_DBALL6",
	"S_EGGSTATUE2",
	"S_ARMA1",
	"S_ARMA2",
	"S_ARMA3",
	"S_ARMA4",
	"S_ARMA5",
	"S_ARMA6",
	"S_ARMA7",
	"S_ARMA8",
	"S_ARMA9",
	"S_ARMA10",
	"S_ARMA11",
	"S_ARMA12",
	"S_ARMA13",
	"S_ARMA14",
	"S_ARMA15",
	"S_ARMA16",
	"S_ARMF1",
	"S_ARMF2",
	"S_ARMF3",
	"S_ARMF4",
	"S_ARMF5",
	"S_ARMF6",
	"S_ARMF7",
	"S_ARMF8",
	"S_ARMF9",
	"S_ARMF10",
	"S_ARMF11",
	"S_ARMF12",
	"S_ARMF13",
	"S_ARMF14",
	"S_ARMF15",
	"S_ARMF16",
	"S_ARMB1",
	"S_ARMB2",
	"S_ARMB3",
	"S_ARMB4",
	"S_ARMB5",
	"S_ARMB6",
	"S_ARMB7",
	"S_ARMB8",
	"S_ARMB9",
	"S_ARMB10",
	"S_ARMB11",
	"S_ARMB12",
	"S_ARMB13",
	"S_ARMB14",
	"S_ARMB15",
	"S_ARMB16",
	"S_WIND1",
	"S_WIND2",
	"S_WIND3",
	"S_WIND4",
	"S_WIND5",
	"S_WIND6",
	"S_WIND7",
	"S_WIND8",
	"S_MAGN1",
	"S_MAGN2",
	"S_MAGN3",
	"S_MAGN4",
	"S_MAGN5",
	"S_MAGN6",
	"S_MAGN7",
	"S_MAGN8",
	"S_MAGN9",
	"S_MAGN10",
	"S_MAGN11",
	"S_MAGN12",
	"S_FORC1",
	"S_FORC2",
	"S_FORC3",
	"S_FORC4",
	"S_FORC5",
	"S_FORC6",
	"S_FORC7",
	"S_FORC8",
	"S_FORC9",
	"S_FORC10",
	"S_FORC11",
	"S_FORC12",
	"S_FORC13",
	"S_FORC14",
	"S_FORC15",
	"S_FORC16",
	"S_FORC17",
	"S_FORC18",
	"S_FORC19",
	"S_FORC20",
	"S_ELEM1",
	"S_ELEM2",
	"S_ELEM3",
	"S_ELEM4",
	"S_ELEM5",
	"S_ELEM6",
	"S_ELEM7",
	"S_ELEM8",
	"S_ELEM9",
	"S_ELEM10",
	"S_ELEM11",
	"S_ELEM12",
	"S_ELEMF1",
	"S_ELEMF2",
	"S_ELEMF3",
	"S_ELEMF4",
	"S_ELEMF5",
	"S_ELEMF6",
	"S_ELEMF7",
	"S_ELEMF8",
	"S_PITY1",
	"S_PITY2",
	"S_PITY3",
	"S_PITY4",
	"S_PITY5",
	"S_PITY6",
	"S_PITY7",
	"S_PITY8",
	"S_PITY9",
	"S_PITY10",
	"S_IVSP",
	"S_SSPK1",
	"S_SSPK2",
	"S_SSPK3",
	"S_SSPK4",
	"S_SSPK5",
	"S_BIRD1",
	"S_BIRD2",
	"S_BIRD3",
	"S_BUNNY1",
	"S_BUNNY2",
	"S_BUNNY3",
	"S_BUNNY4",
	"S_BUNNY5",
	"S_BUNNY6",
	"S_BUNNY7",
	"S_BUNNY8",
	"S_BUNNY9",
	"S_BUNNY10",
	"S_MOUSE1",
	"S_MOUSE2",
	"S_CHICKEN1",
	"S_CHICKENHOP",
	"S_CHICKENFLY1",
	"S_CHICKENFLY2",
	"S_COW1",
	"S_COW2",
	"S_COW3",
	"S_COW4",
	"S_RBIRD1",
	"S_RBIRD2",
	"S_RBIRD3",
	"S_YELLOWSPRING",
	"S_YELLOWSPRING2",
	"S_YELLOWSPRING3",
	"S_YELLOWSPRING4",
	"S_YELLOWSPRING5",
	"S_REDSPRING",
	"S_REDSPRING2",
	"S_REDSPRING3",
	"S_REDSPRING4",
	"S_REDSPRING5",
	"S_BLUESPRING",
	"S_BLUESPRING2",
	"S_BLUESPRING3",
	"S_BLUESPRING4",
	"S_BLUESPRING5",
	"S_YDIAG1",
	"S_YDIAG2",
	"S_YDIAG3",
	"S_YDIAG4",
	"S_YDIAG5",
	"S_YDIAG6",
	"S_YDIAG7",
	"S_YDIAG8",
	"S_RDIAG1",
	"S_RDIAG2",
	"S_RDIAG3",
	"S_RDIAG4",
	"S_RDIAG5",
	"S_RDIAG6",
	"S_RDIAG7",
	"S_RDIAG8",
	"S_RAIN1",
	"S_RAINRETURN",
	"S_SNOW1",
	"S_SNOW2",
	"S_SNOW3",
	"S_SPLISH1",
	"S_SPLISH2",
	"S_SPLISH3",
	"S_SPLISH4",
	"S_SPLISH5",
	"S_SPLISH6",
	"S_SPLISH7",
	"S_SPLISH8",
	"S_SPLISH9",
	"S_SPLASH1",
	"S_SPLASH2",
	"S_SPLASH3",
	"S_SMOKE1",
	"S_SMOKE2",
	"S_SMOKE3",
	"S_SMOKE4",
	"S_SMOKE5",
	"S_SMALLBUBBLE",
	"S_SMALLBUBBLE1",
	"S_MEDIUMBUBBLE",
	"S_MEDIUMBUBBLE1",
	"S_LARGEBUBBLE",
	"S_EXTRALARGEBUBBLE",
	"S_POP1",
	"S_FOG1",
	"S_FOG2",
	"S_FOG3",
	"S_FOG4",
	"S_FOG5",
	"S_FOG6",
	"S_FOG7",
	"S_FOG8",
	"S_FOG9",
	"S_FOG10",
	"S_FOG11",
	"S_FOG12",
	"S_FOG13",
	"S_FOG14",
	"S_SEED",
	"S_PARTICLE",
	"S_PARTICLEGEN",
	"S_SCRA",
	"S_SCRB",
	"S_SCRC",
	"S_SCRD",
	"S_SCRE",
	"S_SCRF",
	"S_SCRG",
	"S_SCRH",
	"S_SCRI",
	"S_SCRJ",
	"S_SCRK",
	"S_ZERO1",
	"S_ONE1",
	"S_TWO1",
	"S_THREE1",
	"S_FOUR1",
	"S_FIVE1",
	"S_TTAG1",
	"S_GOTFLAG1",
	"S_GOTFLAG2",
	"S_GOTFLAG3",
	"S_GOTFLAG4",
	"S_RRNG1",
	"S_RRNG2",
	"S_RRNG3",
	"S_RRNG4",
	"S_RRNG5",
	"S_RRNG6",
	"S_RRNG7",
	"S_BOUNCERINGAMMO",
	"S_RAILRINGAMMO",
	"S_INFINITYRINGAMMO",
	"S_AUTOMATICRINGAMMO",
	"S_EXPLOSIONRINGAMMO",
	"S_SCATTERRINGAMMO",
	"S_GRENADERINGAMMO",
	"S_BOUNCEPICKUP",
	"S_BOUNCEPICKUPFADE1",
	"S_BOUNCEPICKUPFADE2",
	"S_BOUNCEPICKUPFADE3",
	"S_BOUNCEPICKUPFADE4",
	"S_BOUNCEPICKUPFADE5",
	"S_BOUNCEPICKUPFADE6",
	"S_BOUNCEPICKUPFADE7",
	"S_BOUNCEPICKUPFADE8",
	"S_RAILPICKUP",
	"S_RAILPICKUPFADE1",
	"S_RAILPICKUPFADE2",
	"S_RAILPICKUPFADE3",
	"S_RAILPICKUPFADE4",
	"S_RAILPICKUPFADE5",
	"S_RAILPICKUPFADE6",
	"S_RAILPICKUPFADE7",
	"S_RAILPICKUPFADE8",
	"S_AUTOPICKUP",
	"S_AUTOPICKUPFADE1",
	"S_AUTOPICKUPFADE2",
	"S_AUTOPICKUPFADE3",
	"S_AUTOPICKUPFADE4",
	"S_AUTOPICKUPFADE5",
	"S_AUTOPICKUPFADE6",
	"S_AUTOPICKUPFADE7",
	"S_AUTOPICKUPFADE8",
	"S_EXPLODEPICKUP",
	"S_EXPLODEPICKUPFADE1",
	"S_EXPLODEPICKUPFADE2",
	"S_EXPLODEPICKUPFADE3",
	"S_EXPLODEPICKUPFADE4",
	"S_EXPLODEPICKUPFADE5",
	"S_EXPLODEPICKUPFADE6",
	"S_EXPLODEPICKUPFADE7",
	"S_EXPLODEPICKUPFADE8",
	"S_SCATTERPICKUP",
	"S_SCATTERPICKUPFADE1",
	"S_SCATTERPICKUPFADE2",
	"S_SCATTERPICKUPFADE3",
	"S_SCATTERPICKUPFADE4",
	"S_SCATTERPICKUPFADE5",
	"S_SCATTERPICKUPFADE6",
	"S_SCATTERPICKUPFADE7",
	"S_SCATTERPICKUPFADE8",
	"S_GRENADEPICKUP",
	"S_GRENADEPICKUPFADE1",
	"S_GRENADEPICKUPFADE2",
	"S_GRENADEPICKUPFADE3",
	"S_GRENADEPICKUPFADE4",
	"S_GRENADEPICKUPFADE5",
	"S_GRENADEPICKUPFADE6",
	"S_GRENADEPICKUPFADE7",
	"S_GRENADEPICKUPFADE8",
	"S_THROWNBOUNCE1",
	"S_THROWNBOUNCE2",
	"S_THROWNBOUNCE3",
	"S_THROWNBOUNCE4",
	"S_THROWNBOUNCE5",
	"S_THROWNBOUNCE6",
	"S_THROWNBOUNCE7",
	"S_THROWNINFINITY1",
	"S_THROWNINFINITY2",
	"S_THROWNINFINITY3",
	"S_THROWNINFINITY4",
	"S_THROWNINFINITY5",
	"S_THROWNINFINITY6",
	"S_THROWNINFINITY7",
	"S_THROWNAUTOMATIC1",
	"S_THROWNAUTOMATIC2",
	"S_THROWNAUTOMATIC3",
	"S_THROWNAUTOMATIC4",
	"S_THROWNAUTOMATIC5",
	"S_THROWNAUTOMATIC6",
	"S_THROWNAUTOMATIC7",
	"S_THROWNEXPLOSION1",
	"S_THROWNEXPLOSION2",
	"S_THROWNEXPLOSION3",
	"S_THROWNEXPLOSION4",
	"S_THROWNEXPLOSION5",
	"S_THROWNEXPLOSION6",
	"S_THROWNEXPLOSION7",
	"S_THROWNGRENADE1",
	"S_THROWNGRENADE2",
	"S_THROWNGRENADE3",
	"S_THROWNGRENADE4",
	"S_THROWNGRENADE5",
	"S_THROWNGRENADE6",
	"S_THROWNGRENADE7",
	"S_THROWNGRENADE8",
	"S_THROWNGRENADE9",
	"S_THROWNGRENADE10",
	"S_THROWNGRENADE11",
	"S_THROWNGRENADE12",
	"S_THROWNGRENADE13",
	"S_THROWNGRENADE14",
	"S_THROWNGRENADE15",
	"S_THROWNGRENADE16",
	"S_THROWNGRENADE17",
	"S_THROWNGRENADE18",
	"S_THROWNSCATTER",
	"S_RINGEXPLODE",
	"S_COIN1",
	"S_COIN2",
	"S_COIN3",
	"S_COINSPARKLE1",
	"S_COINSPARKLE2",
	"S_COINSPARKLE3",
	"S_COINSPARKLE4",
	"S_GOOMBA1",
	"S_GOOMBA1B",
	"S_GOOMBA2",
	"S_GOOMBA3",
	"S_GOOMBA4",
	"S_GOOMBA5",
	"S_GOOMBA6",
	"S_GOOMBA7",
	"S_GOOMBA8",
	"S_GOOMBA9",
	"S_GOOMBA_DEAD",
	"S_BLUEGOOMBA1",
	"S_BLUEGOOMBA1B",
	"S_BLUEGOOMBA2",
	"S_BLUEGOOMBA3",
	"S_BLUEGOOMBA4",
	"S_BLUEGOOMBA5",
	"S_BLUEGOOMBA6",
	"S_BLUEGOOMBA7",
	"S_BLUEGOOMBA8",
	"S_BLUEGOOMBA9",
	"S_BLUEGOOMBA_DEAD",
	"S_FIREFLOWER1",
	"S_FIREFLOWER2",
	"S_FIREFLOWER3",
	"S_FIREFLOWER4",
	"S_FIREBALL1",
	"S_FIREBALL2",
	"S_FIREBALL3",
	"S_FIREBALL4",
	"S_FIREBALLEXP1",
	"S_FIREBALLEXP2",
	"S_FIREBALLEXP3",
	"S_SHELL",
	"S_SHELL1",
	"S_SHELL2",
	"S_SHELL3",
	"S_SHELL4",
	"S_PUMA1",
	"S_PUMA2",
	"S_PUMA3",
	"S_PUMA4",
	"S_PUMA5",
	"S_PUMA6",
	"S_HAMMER1",
	"S_HAMMER2",
	"S_HAMMER3",
	"S_HAMMER4",
	"S_KOOPA1",
	"S_KOOPA2",
	"S_KOOPAFLAME1",
	"S_KOOPAFLAME2",
	"S_KOOPAFLAME3",
	"S_AXE1",
	"S_AXE2",
	"S_AXE3",
	"S_MARIOBUSH1",
	"S_MARIOBUSH2",
	"S_TOAD",
	"S_NIGHTSDRONE1",
	"S_NIGHTSDRONE2",
	"S_NIGHTSDRONE_SPARKLING1",
	"S_NIGHTSDRONE_SPARKLING2",
	"S_NIGHTSDRONE_SPARKLING3",
	"S_NIGHTSDRONE_SPARKLING4",
	"S_NIGHTSDRONE_SPARKLING5",
	"S_NIGHTSDRONE_SPARKLING6",
	"S_NIGHTSDRONE_SPARKLING7",
	"S_NIGHTSDRONE_SPARKLING8",
	"S_NIGHTSDRONE_SPARKLING9",
	"S_NIGHTSDRONE_SPARKLING10",
	"S_NIGHTSDRONE_SPARKLING11",
	"S_NIGHTSDRONE_SPARKLING12",
	"S_NIGHTSDRONE_SPARKLING13",
	"S_NIGHTSDRONE_SPARKLING14",
	"S_NIGHTSDRONE_SPARKLING15",
	"S_NIGHTSDRONE_SPARKLING16",
	"S_NIGHTSGOAL1",
	"S_NIGHTSGOAL2",
	"S_NIGHTSGOAL3",
	"S_NIGHTSGOAL4",
	"S_NIGHTSFLY1A",
	"S_NIGHTSFLY1B",
	"S_NIGHTSDRILL1A",
	"S_NIGHTSDRILL1B",
	"S_NIGHTSDRILL1C",
	"S_NIGHTSDRILL1D",
	"S_NIGHTSFLY2A",
	"S_NIGHTSFLY2B",
	"S_NIGHTSDRILL2A",
	"S_NIGHTSDRILL2B",
	"S_NIGHTSDRILL2C",
	"S_NIGHTSDRILL2D",
	"S_NIGHTSFLY3A",
	"S_NIGHTSFLY3B",
	"S_NIGHTSDRILL3A",
	"S_NIGHTSDRILL3B",
	"S_NIGHTSDRILL3C",
	"S_NIGHTSDRILL3D",
	"S_NIGHTSFLY4A",
	"S_NIGHTSFLY4B",
	"S_NIGHTSDRILL4A",
	"S_NIGHTSDRILL4B",
	"S_NIGHTSDRILL4C",
	"S_NIGHTSDRILL4D",
	"S_NIGHTSFLY5A",
	"S_NIGHTSFLY5B",
	"S_NIGHTSDRILL5A",
	"S_NIGHTSDRILL5B",
	"S_NIGHTSDRILL5C",
	"S_NIGHTSDRILL5D",
	"S_NIGHTSFLY6A",
	"S_NIGHTSFLY6B",
	"S_NIGHTSDRILL6A",
	"S_NIGHTSDRILL6B",
	"S_NIGHTSDRILL6C",
	"S_NIGHTSDRILL6D",
	"S_NIGHTSFLY7A",
	"S_NIGHTSFLY7B",
	"S_NIGHTSDRILL7A",
	"S_NIGHTSDRILL7B",
	"S_NIGHTSDRILL7C",
	"S_NIGHTSDRILL7D",
	"S_NIGHTSFLY8A",
	"S_NIGHTSFLY8B",
	"S_NIGHTSDRILL8A",
	"S_NIGHTSDRILL8B",
	"S_NIGHTSDRILL8C",
	"S_NIGHTSDRILL8D",
	"S_NIGHTSFLY9A",
	"S_NIGHTSFLY9B",
	"S_NIGHTSDRILL9A",
	"S_NIGHTSDRILL9B",
	"S_NIGHTSDRILL9C",
	"S_NIGHTSDRILL9D",
	"S_NIGHTSHURT1",
	"S_NIGHTSHURT2",
	"S_NIGHTSHURT3",
	"S_NIGHTSHURT4",
	"S_NIGHTSHURT5",
	"S_NIGHTSHURT6",
	"S_NIGHTSHURT7",
	"S_NIGHTSHURT8",
	"S_NIGHTSHURT9",
	"S_NIGHTSHURT10",
	"S_NIGHTSHURT11",
	"S_NIGHTSHURT12",
	"S_NIGHTSHURT13",
	"S_NIGHTSHURT14",
	"S_NIGHTSHURT15",
	"S_NIGHTSHURT16",
	"S_NIGHTSHURT17",
	"S_NIGHTSHURT18",
	"S_NIGHTSHURT19",
	"S_NIGHTSHURT20",
	"S_NIGHTSHURT21",
	"S_NIGHTSHURT22",
	"S_NIGHTSHURT23",
	"S_NIGHTSHURT24",
	"S_NIGHTSHURT25",
	"S_NIGHTSHURT26",
	"S_NIGHTSHURT27",
	"S_NIGHTSHURT28",
	"S_NIGHTSHURT29",
	"S_NIGHTSHURT30",
	"S_NIGHTSHURT31",
	"S_NIGHTSHURT32",
	"S_NIGHTSPARKLE1",
	"S_NIGHTSPARKLE2",
	"S_NIGHTSPARKLE3",
	"S_NIGHTSPARKLE4",
	"S_NIGHTSPARKLESUPER1",
	"S_NIGHTSPARKLESUPER2",
	"S_NIGHTSPARKLESUPER3",
	"S_NIGHTSPARKLESUPER4",
	"S_NIGHTSLOOPHELPER",
	"S_NIGHTSBUMPER1",
	"S_NIGHTSBUMPER2",
	"S_NIGHTSBUMPER3",
	"S_NIGHTSBUMPER4",
	"S_NIGHTSBUMPER5",
	"S_NIGHTSBUMPER6",
	"S_NIGHTSBUMPER7",
	"S_NIGHTSBUMPER8",
	"S_NIGHTSBUMPER9",
	"S_NIGHTSBUMPER10",
	"S_NIGHTSBUMPER11",
	"S_NIGHTSBUMPER12",
	"S_HOOP",
	"S_HOOP_XMASA",
	"S_HOOP_XMASB",
	"S_NIGHTSCORE10",
	"S_NIGHTSCORE20",
	"S_NIGHTSCORE30",
	"S_NIGHTSCORE40",
	"S_NIGHTSCORE50",
	"S_NIGHTSCORE60",
	"S_NIGHTSCORE70",
	"S_NIGHTSCORE80",
	"S_NIGHTSCORE90",
	"S_NIGHTSCORE100",
	"S_NIGHTSCORE10_2",
	"S_NIGHTSCORE20_2",
	"S_NIGHTSCORE30_2",
	"S_NIGHTSCORE40_2",
	"S_NIGHTSCORE50_2",
	"S_NIGHTSCORE60_2",
	"S_NIGHTSCORE70_2",
	"S_NIGHTSCORE80_2",
	"S_NIGHTSCORE90_2",
	"S_NIGHTSCORE100_2",
	"S_NIGHTSWING",
	"S_NIGHTSWING_XMAS",
	"S_NIGHTSPOWERUP1",
	"S_NIGHTSPOWERUP2",
	"S_NIGHTSPOWERUP3",
	"S_NIGHTSPOWERUP4",
	"S_NIGHTSPOWERUP5",
	"S_NIGHTSPOWERUP6",
	"S_NIGHTSPOWERUP7",
	"S_NIGHTSPOWERUP8",
	"S_NIGHTSPOWERUP9",
	"S_NIGHTSPOWERUP10",
	"S_EGGCAPSULE",
	"S_ORBITEM1",
	"S_ORBITEM2",
	"S_ORBITEM3",
	"S_ORBITEM4",
	"S_ORBITEM5",
	"S_ORBITEM6",
	"S_ORBITEM7",
	"S_ORBITEM8",
	"S_ORBITEM9",
	"S_ORBITEM10",
	"S_ORBITEM11",
	"S_ORBITEM12",
	"S_ORBITEM13",
	"S_ORBITEM14",
	"S_ORBITEM15",
	"S_ORBITEM16",
	"S_NIGHTOPIANHELPER1",
	"S_NIGHTOPIANHELPER2",
	"S_NIGHTOPIANHELPER3",
	"S_NIGHTOPIANHELPER4",
	"S_NIGHTOPIANHELPER5",
	"S_NIGHTOPIANHELPER6",
	"S_NIGHTOPIANHELPER7",
	"S_NIGHTOPIANHELPER8",
	"S_CRUMBLE1",
	"S_CRUMBLE2",
	"S_SUPERTRANS1",
	"S_SUPERTRANS2",
	"S_SUPERTRANS3",
	"S_SUPERTRANS4",
	"S_SUPERTRANS5",
	"S_SUPERTRANS6",
	"S_SUPERTRANS7",
	"S_SUPERTRANS8",
	"S_SUPERTRANS9",
	"S_SPRK1",
	"S_SPRK2",
	"S_SPRK3",
	"S_SPRK4",
	"S_SPRK5",
	"S_SPRK6",
	"S_SPRK7",
	"S_SPRK8",
	"S_SPRK9",
	"S_SPRK10",
	"S_SPRK11",
	"S_SPRK12",
	"S_SPRK13",
	"S_SPRK14",
	"S_SPRK15",
	"S_SPRK16",
	"S_XPLD1",
	"S_XPLD2",
	"S_XPLD3",
	"S_XPLD4",
	"S_WPLD1",
	"S_WPLD2",
	"S_WPLD3",
	"S_WPLD4",
	"S_WPLD5",
	"S_WPLD6",
	"S_ROCKSPAWN",
	"S_ROCKCRUMBLEA",
	"S_ROCKCRUMBLEB",
	"S_ROCKCRUMBLEC",
	"S_ROCKCRUMBLED",
	"S_ROCKCRUMBLEE",
	"S_ROCKCRUMBLEF",
	"S_ROCKCRUMBLEG",
	"S_ROCKCRUMBLEH",
	"S_ROCKCRUMBLEI",
	"S_ROCKCRUMBLEJ",
	"S_ROCKCRUMBLEK",
	"S_ROCKCRUMBLEL",
	"S_ROCKCRUMBLEM",
	"S_ROCKCRUMBLEN",
	"S_ROCKCRUMBLEO",
	"S_ROCKCRUMBLEP",
	"S_SRB1_CRAWLA1",
	"S_SRB1_CRAWLA2",
	"S_SRB1_CRAWLA3",
	"S_SRB1_CRAWLA4",
	"S_SRB1_BAT1",
	"S_SRB1_BAT2",
	"S_SRB1_BAT3",
	"S_SRB1_BAT4",
	"S_SRB1_ROBOFISH1",
	"S_SRB1_ROBOFISH2",
	"S_SRB1_ROBOFISH3",
	"S_SRB1_VOLCANOGUY1",
	"S_SRB1_VOLCANOGUY2",
	"S_SRB1_HOPPY1",
	"S_SRB1_HOPPY2",
	"S_SRB1_HOPPYWATER1",
	"S_SRB1_HOPPYWATER2",
	"S_SRB1_HOPPYSKYLAB1",
	"S_SRB1_MMZFLYING1",
	"S_SRB1_MMZFLYING2",
	"S_SRB1_MMZFLYING3",
	"S_SRB1_MMZFLYING4",
	"S_SRB1_MMZFLYING5",
	"S_SRB1_UFO1",
	"S_SRB1_UFO2",
	"S_SRB1_GRAYBOT1",
	"S_SRB1_GRAYBOT2",
	"S_SRB1_GRAYBOT3",
	"S_SRB1_GRAYBOT4",
	"S_SRB1_GRAYBOT5",
	"S_SRB1_GRAYBOT6",
	"S_SRB1_ROBOTOPOLIS1",
	"S_SRB1_ROBOTOPOLIS2",
	"S_SRB1_RBZBUZZ1",
	"S_SRB1_RBZBUZZ2",
	"S_SRB1_RBZSPIKES1",
	"S_SRB1_RBZSPIKES2",
	"S_SRB1_METALSONIC1",
	"S_SRB1_METALSONIC2",
	"S_SRB1_METALSONIC3",
	"S_SRB1_GOLDBOT1",
	"S_SRB1_GOLDBOT2",
	"S_SRB1_GOLDBOT3",
	"S_SRB1_GOLDBOT4",
	"S_SRB1_GOLDBOT5",
	"S_SRB1_GOLDBOT6",
	"S_SRB1_GENREX1",
	"S_SRB1_GENREX2",
	"S_GRAYSPRING",
	"S_GRAYSPRING2",
	"S_GRAYSPRING3",
	"S_GRAYSPRING4",
	"S_GRAYSPRING5",
	"S_INVISSPRING",
	"S_BDIAG1",
	"S_BDIAG2",
	"S_BDIAG3",
	"S_BDIAG4",
	"S_BDIAG5",
	"S_BDIAG6",
	"S_BDIAG7",
	"S_BDIAG8",
	"S_RANDOMITEM1",
	"S_RANDOMITEM2",
	"S_RANDOMITEM3",
	"S_RANDOMITEM4",
	"S_RANDOMITEM5",
	"S_RANDOMITEM6",
	"S_RANDOMITEM7",
	"S_RANDOMITEM8",
	"S_RANDOMITEM9",
	"S_RANDOMITEM10",
	"S_RANDOMITEM11",
	"S_RANDOMITEM12",
	"S_RANDOMITEM13",
	"S_RANDOMITEM14",
	"S_RANDOMITEM15",
	"S_RANDOMITEM16",
	"S_RANDOMITEM17",
	"S_RANDOMITEM18",
	"S_RANDOMITEM19",
	"S_RANDOMITEM20",
	"S_RANDOMITEM21",
	"S_RANDOMITEM22",
	"S_RANDOMITEM23",
	"S_RANDOMITEM24",
	"S_DEADRANDOMITEM",
	"S_RANDOMITEMPOP1",
	"S_RANDOMITEMPOP2",
	"S_RANDOMITEMPOP3",
	"S_RANDOMITEMPOP4",
	"S_ITEMICON",
	"S_SIGNSPARK1",
	"S_SIGNSPARK2",
	"S_SIGNSPARK3",
	"S_SIGNSPARK4",
	"S_SIGNSPARK5",
	"S_SIGNSPARK6",
	"S_SIGNSPARK7",
	"S_SIGNSPARK8",
	"S_SIGNSPARK9",
	"S_SIGNSPARK10",
	"S_SIGNSPARK11",
	"S_DRIFTSPARK_A1",
	"S_DRIFTSPARK_A2",
	"S_DRIFTSPARK_A3",
	"S_DRIFTSPARK_B1",
	"S_DRIFTSPARK_C1",
	"S_DRIFTSPARK_C2",
	"S_BRAKEDRIFT",
	"S_DRIFTDUST1",
	"S_DRIFTDUST2",
	"S_DRIFTDUST3",
	"S_DRIFTDUST4",
	"S_FASTLINE1",
	"S_FASTLINE2",
	"S_FASTLINE3",
	"S_FASTLINE4",
	"S_FASTLINE5",
	"S_FASTDUST1",
	"S_FASTDUST2",
	"S_FASTDUST3",
	"S_FASTDUST4",
	"S_FASTDUST5",
	"S_FASTDUST6",
	"S_FASTDUST7",
	"S_BOOSTFLAME",
	"S_BOOSTSMOKESPAWNER",
	"S_BOOSTSMOKE1",
	"S_BOOSTSMOKE2",
	"S_BOOSTSMOKE3",
	"S_BOOSTSMOKE4",
	"S_BOOSTSMOKE5",
	"S_BOOSTSMOKE6",
	"S_KARTFIRE1",
	"S_KARTFIRE2",
	"S_KARTFIRE3",
	"S_KARTFIRE4",
	"S_KARTFIRE5",
	"S_KARTFIRE6",
	"S_KARTFIRE7",
	"S_KARTFIRE8",
	"S_KARTAIZDRIFTSTRAT",
	"S_KARTINVULN_SMALL1",
	"S_KARTINVULN_SMALL2",
	"S_KARTINVULN_SMALL3",
	"S_KARTINVULN_SMALL4",
	"S_KARTINVULN_SMALL5",
	"S_KARTINVULN_LARGE1",
	"S_KARTINVULN_LARGE2",
	"S_KARTINVULN_LARGE3",
	"S_KARTINVULN_LARGE4",
	"S_KARTINVULN_LARGE5",
	"S_INVULNFLASH1",
	"S_INVULNFLASH2",
	"S_INVULNFLASH3",
	"S_INVULNFLASH4",
	"S_WIPEOUTTRAIL1",
	"S_WIPEOUTTRAIL2",
	"S_WIPEOUTTRAIL3",
	"S_WIPEOUTTRAIL4",
	"S_WIPEOUTTRAIL5",
	"S_ROCKETSNEAKER_L",
	"S_ROCKETSNEAKER_R",
	"S_ROCKETSNEAKER_LVIBRATE",
	"S_ROCKETSNEAKER_RVIBRATE",
	"S_EGGMANITEM1",
	"S_EGGMANITEM2",
	"S_EGGMANITEM3",
	"S_EGGMANITEM4",
	"S_EGGMANITEM5",
	"S_EGGMANITEM6",
	"S_EGGMANITEM7",
	"S_EGGMANITEM8",
	"S_EGGMANITEM9",
	"S_EGGMANITEM10",
	"S_EGGMANITEM11",
	"S_EGGMANITEM12",
	"S_EGGMANITEM13",
	"S_EGGMANITEM14",
	"S_EGGMANITEM15",
	"S_EGGMANITEM16",
	"S_EGGMANITEM17",
	"S_EGGMANITEM18",
	"S_EGGMANITEM19",
	"S_EGGMANITEM20",
	"S_EGGMANITEM21",
	"S_EGGMANITEM22",
	"S_EGGMANITEM23",
	"S_EGGMANITEM24",
	"S_EGGMANITEM_DEAD",
	"S_BANANA",
	"S_BANANA_DEAD",
	"S_ORBINAUT1",
	"S_ORBINAUT2",
	"S_ORBINAUT3",
	"S_ORBINAUT4",
	"S_ORBINAUT5",
	"S_ORBINAUT6",
	"S_ORBINAUT_DEAD",
	"S_ORBINAUT_SHIELD1",
	"S_ORBINAUT_SHIELD2",
	"S_ORBINAUT_SHIELD3",
	"S_ORBINAUT_SHIELD4",
	"S_ORBINAUT_SHIELD5",
	"S_ORBINAUT_SHIELD6",
	"S_ORBINAUT_SHIELDDEAD",
	"S_JAWZ1",
	"S_JAWZ2",
	"S_JAWZ3",
	"S_JAWZ4",
	"S_JAWZ5",
	"S_JAWZ6",
	"S_JAWZ7",
	"S_JAWZ8",
	"S_JAWZ_DUD1",
	"S_JAWZ_DUD2",
	"S_JAWZ_DUD3",
	"S_JAWZ_DUD4",
	"S_JAWZ_DUD5",
	"S_JAWZ_DUD6",
	"S_JAWZ_DUD7",
	"S_JAWZ_DUD8",
	"S_JAWZ_SHIELD1",
	"S_JAWZ_SHIELD2",
	"S_JAWZ_SHIELD3",
	"S_JAWZ_SHIELD4",
	"S_JAWZ_SHIELD5",
	"S_JAWZ_SHIELD6",
	"S_JAWZ_SHIELD7",
	"S_JAWZ_SHIELD8",
	"S_JAWZ_DEAD1",
	"S_JAWZ_DEAD2",
	"S_PLAYERRETICULE",
	"S_SSMINE1",
	"S_SSMINE2",
	"S_SSMINE3",
	"S_SSMINE4",
	"S_SSMINE_SHIELD1",
	"S_SSMINE_SHIELD2",
	"S_SSMINE_AIR1",
	"S_SSMINE_AIR2",
	"S_SSMINE_DEPLOY1",
	"S_SSMINE_DEPLOY2",
	"S_SSMINE_DEPLOY3",
	"S_SSMINE_DEPLOY4",
	"S_SSMINE_DEPLOY5",
	"S_SSMINE_DEPLOY6",
	"S_SSMINE_DEPLOY7",
	"S_SSMINE_DEPLOY8",
	"S_SSMINE_DEPLOY9",
	"S_SSMINE_DEPLOY10",
	"S_SSMINE_DEPLOY11",
	"S_SSMINE_DEPLOY12",
	"S_SSMINE_DEPLOY13",
	"S_SSMINE_EXPLODE",
	"S_MINEEXPLOSION1",
	"S_MINEEXPLOSION2",
	"S_QUICKBOOM1",
	"S_QUICKBOOM2",
	"S_QUICKBOOM3",
	"S_QUICKBOOM4",
	"S_QUICKBOOM5",
	"S_QUICKBOOM6",
	"S_QUICKBOOM7",
	"S_QUICKBOOM8",
	"S_QUICKBOOM9",
	"S_QUICKBOOM10",
	"S_SLOWBOOM1",
	"S_SLOWBOOM2",
	"S_SLOWBOOM3",
	"S_SLOWBOOM4",
	"S_SLOWBOOM5",
	"S_SLOWBOOM6",
	"S_SLOWBOOM7",
	"S_SLOWBOOM8",
	"S_SLOWBOOM9",
	"S_SLOWBOOM10",
	"S_BALLHOG1",
	"S_BALLHOG2",
	"S_BALLHOG3",
	"S_BALLHOG4",
	"S_BALLHOG5",
	"S_BALLHOG6",
	"S_BALLHOG7",
	"S_BALLHOG8",
	"S_BALLHOG_DEAD",
	"S_BALLHOGBOOM1",
	"S_BALLHOGBOOM2",
	"S_BALLHOGBOOM3",
	"S_BALLHOGBOOM4",
	"S_BALLHOGBOOM5",
	"S_BALLHOGBOOM6",
	"S_BALLHOGBOOM7",
	"S_BALLHOGBOOM8",
	"S_BALLHOGBOOM9",
	"S_BALLHOGBOOM10",
	"S_BALLHOGBOOM11",
	"S_BALLHOGBOOM12",
	"S_BALLHOGBOOM13",
	"S_BALLHOGBOOM14",
	"S_BALLHOGBOOM15",
	"S_BALLHOGBOOM16",
	"S_SPB1",
	"S_SPB2",
	"S_SPB3",
	"S_SPB4",
	"S_SPB5",
	"S_SPB6",
	"S_SPB7",
	"S_SPB8",
	"S_SPB9",
	"S_SPB10",
	"S_SPB11",
	"S_SPB12",
	"S_SPB13",
	"S_SPB14",
	"S_SPB15",
	"S_SPB16",
	"S_SPB17",
	"S_SPB18",
	"S_SPB19",
	"S_SPB20",
	"S_SPB_DEAD",
	"S_THUNDERSHIELD1",
	"S_THUNDERSHIELD2",
	"S_THUNDERSHIELD3",
	"S_THUNDERSHIELD4",
	"S_THUNDERSHIELD5",
	"S_THUNDERSHIELD6",
	"S_THUNDERSHIELD7",
	"S_THUNDERSHIELD8",
	"S_THUNDERSHIELD9",
	"S_THUNDERSHIELD10",
	"S_THUNDERSHIELD11",
	"S_THUNDERSHIELD12",
	"S_THUNDERSHIELD13",
	"S_THUNDERSHIELD14",
	"S_THUNDERSHIELD15",
	"S_THUNDERSHIELD16",
	"S_THUNDERSHIELD17",
	"S_THUNDERSHIELD18",
	"S_THUNDERSHIELD19",
	"S_THUNDERSHIELD20",
	"S_THUNDERSHIELD21",
	"S_THUNDERSHIELD22",
	"S_THUNDERSHIELD23",
	"S_THUNDERSHIELD24",
	"S_SINK",
	"S_SINK_SHIELD",
	"S_SINKTRAIL1",
	"S_SINKTRAIL2",
	"S_SINKTRAIL3",
	"S_BATTLEBUMPER1",
	"S_BATTLEBUMPER2",
	"S_BATTLEBUMPER3",
	"S_DEZLASER",
	"S_RANDOMAUDIENCE",
	"S_AUDIENCE_CHAO_CHEER1",
	"S_AUDIENCE_CHAO_CHEER2",
	"S_AUDIENCE_CHAO_WIN1",
	"S_AUDIENCE_CHAO_WIN2",
	"S_AUDIENCE_CHAO_LOSE",
	"S_FLAYM1",
	"S_FLAYM2",
	"S_FLAYM3",
	"S_FLAYM4",
	"S_DEVIL",
	"S_ANGEL",
	"S_PALMTREE",
	"S_FLAG",
	"S_HEDGEHOG",
	"S_BUSH1",
	"S_TWEE",
	"S_HYDRANT",
	"S_BIGPUMA1",
	"S_BIGPUMA2",
	"S_BIGPUMA3",
	"S_BIGPUMA4",
	"S_BIGPUMA5",
	"S_BIGPUMA6",
	"S_APPLE1",
	"S_APPLE2",
	"S_APPLE3",
	"S_APPLE4",
	"S_APPLE5",
	"S_APPLE6",
	"S_APPLE7",
	"S_APPLE8",
	"S_DOOD_FLOWER1",
	"S_DOOD_FLOWER2",
	"S_DOOD_FLOWER3",
	"S_DOOD_FLOWER4",
	"S_DOOD_FLOWER5",
	"S_DOOD_FLOWER6",
	"S_DOOD_BOX1",
	"S_DOOD_BOX2",
	"S_DOOD_BOX3",
	"S_DOOD_BOX4",
	"S_DOOD_BOX5",
	"S_DOOD_BALLOON",
	"S_BIGRING01",
	"S_BIGRING02",
	"S_BIGRING03",
	"S_BIGRING04",
	"S_BIGRING05",
	"S_BIGRING06",
	"S_BIGRING07",
	"S_BIGRING08",
	"S_BIGRING09",
	"S_BIGRING10",
	"S_BIGRING11",
	"S_BIGRING12",
	"S_SNES_DONUTBUSH1",
	"S_SNES_DONUTBUSH2",
	"S_SNES_DONUTBUSH3",
	"S_GBA_BOO1",
	"S_GBA_BOO2",
	"S_GBA_BOO3",
	"S_GBA_BOO4",
	"S_BUZZBOMBER_LOOK1",
	"S_BUZZBOMBER_LOOK2",
	"S_BUZZBOMBER_FLY1",
	"S_BUZZBOMBER_FLY2",
	"S_BUZZBOMBER_FLY3",
	"S_BUZZBOMBER_FLY4",
	"S_CHOMPER_SPAWN",
	"S_CHOMPER_HOP1",
	"S_CHOMPER_HOP2",
	"S_CHOMPER_TURNAROUND",
	"S_PALMTREE2",
	"S_PURPLEFLOWER1",
	"S_PURPLEFLOWER2",
	"S_YELLOWFLOWER1",
	"S_YELLOWFLOWER2",
	"S_PLANT2",
	"S_PLANT3",
	"S_PLANT4",
	"S_SKULL",
	"S_PHANTREE",
	"S_FLYINGGARG1",
	"S_FLYINGGARG2",
	"S_FLYINGGARG3",
	"S_FLYINGGARG4",
	"S_FLYINGGARG5",
	"S_FLYINGGARG6",
	"S_FLYINGGARG7",
	"S_FLYINGGARG8",
	"S_LAMPPOST",
	"S_MOSSYTREE",
	"S_SHADOW",
	"S_WHITESHADOW",
	"S_BUMP1",
	"S_BUMP2",
	"S_BUMP3",
	"S_FLINGENERGY1",
	"S_FLINGENERGY2",
	"S_FLINGENERGY3",
	"S_CLASH1",
	"S_CLASH2",
	"S_CLASH3",
	"S_CLASH4",
	"S_CLASH5",
	"S_CLASH6",
	"S_FIREDITEM1",
	"S_FIREDITEM2",
	"S_FIREDITEM3",
	"S_FIREDITEM4",
	"S_INSTASHIELDA1",
	"S_INSTASHIELDA2",
	"S_INSTASHIELDA3",
	"S_INSTASHIELDA4",
	"S_INSTASHIELDA5",
	"S_INSTASHIELDA6",
	"S_INSTASHIELDA7",
	"S_INSTASHIELDB1",
	"S_INSTASHIELDB2",
	"S_INSTASHIELDB3",
	"S_INSTASHIELDB4",
	"S_INSTASHIELDB5",
	"S_INSTASHIELDB6",
	"S_INSTASHIELDB7",
	"S_PLAYERARROW",
	"S_PLAYERARROW_BOX",
	"S_PLAYERARROW_ITEM",
	"S_PLAYERARROW_NUMBER",
	"S_PLAYERARROW_X",
	"S_PLAYERARROW_WANTED1",
	"S_PLAYERARROW_WANTED2",
	"S_PLAYERARROW_WANTED3",
	"S_PLAYERARROW_WANTED4",
	"S_PLAYERARROW_WANTED5",
	"S_PLAYERARROW_WANTED6",
	"S_PLAYERARROW_WANTED7",
	"S_PLAYERBOMB1",
	"S_PLAYERBOMB2",
	"S_PLAYERBOMB3",
	"S_PLAYERBOMB4",
	"S_PLAYERBOMB5",
	"S_PLAYERBOMB6",
	"S_PLAYERBOMB7",
	"S_PLAYERBOMB8",
	"S_PLAYERBOMB9",
	"S_PLAYERBOMB10",
	"S_PLAYERBOMB11",
	"S_PLAYERBOMB12",
	"S_PLAYERBOMB13",
	"S_PLAYERBOMB14",
	"S_PLAYERBOMB15",
	"S_PLAYERBOMB16",
	"S_PLAYERBOMB17",
	"S_PLAYERBOMB18",
	"S_PLAYERBOMB19",
	"S_PLAYERBOMB20",
	"S_PLAYERITEM",
	"S_PLAYERFAKE",
	"S_KARMAWHEEL",
	"S_BATTLEPOINT1A",
	"S_BATTLEPOINT1B",
	"S_BATTLEPOINT1C",
	"S_BATTLEPOINT1D",
	"S_BATTLEPOINT1E",
	"S_BATTLEPOINT1F",
	"S_BATTLEPOINT1G",
	"S_BATTLEPOINT1H",
	"S_BATTLEPOINT1I",
	"S_BATTLEPOINT2A",
	"S_BATTLEPOINT2B",
	"S_BATTLEPOINT2C",
	"S_BATTLEPOINT2D",
	"S_BATTLEPOINT2E",
	"S_BATTLEPOINT2F",
	"S_BATTLEPOINT2G",
	"S_BATTLEPOINT2H",
	"S_BATTLEPOINT2I",
	"S_BATTLEPOINT3A",
	"S_BATTLEPOINT3B",
	"S_BATTLEPOINT3C",
	"S_BATTLEPOINT3D",
	"S_BATTLEPOINT3E",
	"S_BATTLEPOINT3F",
	"S_BATTLEPOINT3G",
	"S_BATTLEPOINT3H",
	"S_BATTLEPOINT3I",
	"S_KSPARK1",
	"S_KSPARK2",
	"S_KSPARK3",
	"S_KSPARK4",
	"S_KSPARK5",
	"S_KSPARK6",
	"S_KSPARK7",
	"S_KSPARK8",
	"S_KSPARK9",
	"S_KSPARK10",
	"S_KSPARK11",
	"S_KSPARK12",
	"S_KSPARK13",
	"S_LZIO11",
	"S_LZIO12",
	"S_LZIO13",
	"S_LZIO14",
	"S_LZIO15",
	"S_LZIO16",
	"S_LZIO17",
	"S_LZIO18",
	"S_LZIO19",
	"S_LZIO21",
	"S_LZIO22",
	"S_LZIO23",
	"S_LZIO24",
	"S_LZIO25",
	"S_LZIO26",
	"S_LZIO27",
	"S_LZIO28",
	"S_LZIO29",
	"S_KLIT1",
	"S_KLIT2",
	"S_KLIT3",
	"S_KLIT4",
	"S_KLIT5",
	"S_KLIT6",
	"S_KLIT7",
	"S_KLIT8",
	"S_KLIT9",
	"S_KLIT10",
	"S_KLIT11",
	"S_KLIT12",
	"S_FZEROSMOKE1",
	"S_FZEROSMOKE2",
	"S_FZEROSMOKE3",
	"S_FZEROSMOKE4",
	"S_FZEROSMOKE5",
	"S_FZEROBOOM1",
	"S_FZEROBOOM2",
	"S_FZEROBOOM3",
	"S_FZEROBOOM4",
	"S_FZEROBOOM5",
	"S_FZEROBOOM6",
	"S_FZEROBOOM7",
	"S_FZEROBOOM8",
	"S_FZEROBOOM9",
	"S_FZEROBOOM10",
	"S_FZEROBOOM11",
	"S_FZEROBOOM12",
	"S_FZSLOWSMOKE1",
	"S_FZSLOWSMOKE2",
	"S_FZSLOWSMOKE3",
	"S_FZSLOWSMOKE4",
	"S_FZSLOWSMOKE5",
	"S_SONICBUSH",
	"S_FLAMEPARTICLE",
	"S_MARBLETORCH",
	"S_MARBLELIGHT",
	"S_MARBLEBURNER",
	"S_CDUFO",
	"S_CDUFO_DIE",
	"S_RUSTYLAMP_ORANGE",
	"S_RUSTYCHAIN",
	"S_BALLOON",
	"S_BALLOONPOP1",
	"S_BALLOONPOP2",
	"S_BALLOONPOP3",
	"S_PETSMOKE0",
	"S_PETSMOKE1",
	"S_PETSMOKE2",
	"S_PETSMOKE3",
	"S_PETSMOKE4",
	"S_PETSMOKE5",
	"S_VVVAPING0",
	"S_VVVAPING1",
	"S_VVVAPING2",
	"S_VVVAPING3",
	"S_VVVAPING4",
	"S_VVVAPING5",
	"S_VVVAPE",
	"S_HTZTREE",
	"S_HTZBUSH",
	"S_SGVINE1",
	"S_SGVINE2",
	"S_SGVINE3",
	"S_PGTREE",
	"S_PGFLOWER1",
	"S_PGFLOWER2",
	"S_PGFLOWER3",
	"S_PGBUSH",
	"S_DHPILLAR",
	"S_SPOTLIGHT",
	"S_RANDOMSHADOW",
	"S_GARU1",
	"S_GARU2",
	"S_GARU3",
	"S_TGARU",
	"S_TGARU1",
	"S_TGARU2",
	"S_TGARU3",
	"S_ROAMINGSHADOW",
	"S_MAYONAKAARROW",
	"S_REAPER_INVIS",
	"S_REAPER",
	"S_MEMENTOSTP",
	"S_JITB1",
	"S_JITB2",
	"S_JITB3",
	"S_JITB4",
	"S_JITB5",
	"S_JITB6",
	"S_CDMOONSP",
	"S_CDBUSHSP",
	"S_CDTREEASP",
	"S_CDTREEBSP",
	"S_PINETREE",
	"S_PINETREE_SIDE",
	"S_EZZPROPELLER",
	"S_EZZPROPELLER_BLADE",
	"S_DP_PALMTREE",
	"S_AAZTREE_SEG",
	"S_AAZTREE_COCONUT",
	"S_AAZTREE_LEAF",
	"S_BBZDUST1",
	"S_BBZDUST2",
	"S_BBZDUST3",
	"S_BBZDUST4",
	"S_FROGGER",
	"S_FROGGER_ATTACK",
	"S_FROGGER_JUMP",
	"S_FROGTONGUE",
	"S_FROGTONGUE_JOINT",
	"S_ROBRA",
	"S_ROBRA_HEAD",
	"S_ROBRA_JOINT",
	"S_ROBRASHELL_INSIDE",
	"S_ROBRASHELL_OUTSIDE",
	"S_BLUEROBRA",
	"S_BLUEROBRA_HEAD",
	"S_BLUEROBRA_JOINT",
	"S_EERIEFOG1",
	"S_EERIEFOG2",
	"S_EERIEFOG3",
	"S_EERIEFOG4",
	"S_EERIEFOG5",
	"S_SMK_PIPE1",
	"S_SMK_PIPE2",
	"S_SMK_MOLE",
	"S_SMK_THWOMP",
	"S_SMK_SNOWBALL",
	"S_SMK_ICEBLOCK",
	"S_SMK_ICEBLOCK2",
	"S_SMK_ICEBLOCK_DEBRIS",
	"S_SMK_ICEBLOCK_DEBRIS2",
	"S_BLUEFIRE1",
	"S_BLUEFIRE2",
	"S_BLUEFIRE3",
	"S_BLUEFIRE4",
	"S_GREENFIRE1",
	"S_GREENFIRE2",
	"S_GREENFIRE3",
	"S_GREENFIRE4",
	"S_REGALCHEST",
	"S_CHIMERASTATUE",
	"S_DRAGONSTATUE",
	"S_LIZARDMANSTATUE",
	"S_PEGASUSSTATUE",
	"S_ZELDAFIRE1",
	"S_ZELDAFIRE2",
	"S_ZELDAFIRE3",
	"S_ZELDAFIRE4",
	"S_GANBARETHING",
	"S_GANBAREDUCK",
	"S_GANBARETREE",
	"S_MONOIDLE",
	"S_MONOCHASE1",
	"S_MONOCHASE2",
	"S_MONOCHASE3",
	"S_MONOCHASE4",
	"S_MONOPAIN",
	"S_REDZELDAFIRE1",
	"S_REDZELDAFIRE2",
	"S_REDZELDAFIRE3",
	"S_REDZELDAFIRE4",
	"S_BOWLINGPIN",
	"S_BOWLINGHIT1",
	"S_BOWLINGHIT2",
	"S_BOWLINGHIT3",
	"S_BOWLINGHIT4",
	"S_ARIDTOAD",
	"S_TOADHIT1",
	"S_TOADHIT2",
	"S_TOADHIT3",
	"S_TOADHIT4",
	"S_EBARRELIDLE",
	"S_EBARREL1",
	"S_EBARREL2",
	"S_EBARREL3",
	"S_EBARREL4",
	"S_EBARREL5",
	"S_EBARREL6",
	"S_EBARREL7",
	"S_EBARREL8",
	"S_EBARREL9",
	"S_EBARREL10",
	"S_EBARREL11",
	"S_EBARREL12",
	"S_EBARREL13",
	"S_EBARREL14",
	"S_EBARREL15",
	"S_EBARREL16",
	"S_EBARREL17",
	"S_EBARREL18",
	"S_MERRYHORSE",
	"S_BLUEFRUIT",
	"S_ORANGEFRUIT",
	"S_REDFRUIT",
	"S_PINKFRUIT",
	"S_ADVENTURESPIKEA1",
	"S_ADVENTURESPIKEA2",
	"S_ADVENTURESPIKEB1",
	"S_ADVENTURESPIKEB2",
	"S_ADVENTURESPIKEC1",
	"S_ADVENTURESPIKEC2",
	"S_BOOSTPROMPT1",
	"S_BOOSTPROMPT2",
	"S_BOOSTOFF1",
	"S_BOOSTOFF2",
	"S_BOOSTON1",
	"S_BOOSTON2",
	"S_LIZARDMAN",
	"S_LIONMAN",
	"S_OPULENCE_PALMTREE",
	"S_OPULENCE_FERN",
	"S_TUMBLEGEM_IDLE",
	"S_TUMBLEGEM_ROLL",
	"S_TUMBLECOIN_IDLE",
	"S_TUMBLECOIN_FLIP",
	"S_KARMAFIREWORK1",
	"S_KARMAFIREWORK2",
	"S_KARMAFIREWORK3",
	"S_KARMAFIREWORK4",
	"S_KARMAFIREWORKTRAIL",
	"S_OPAQUESMOKE1",
	"S_OPAQUESMOKE2",
	"S_OPAQUESMOKE3",
	"S_OPAQUESMOKE4",
	"S_OPAQUESMOKE5",
	"S_NAMECHECK",
}

globalize(mobjs)
globalize(stats)
firstmt = #mobjs + 1
firststate = #stats + 1
